@@ -1,3 +1,5 @@
+#include "config.h"
+
 #include <telepathy-glib/telepathy-glib.h>
 
 static GMainLoop *loop = NULL;
@@ -12,12 +14,12 @@ channel_closed_cb (GObject *object,
 
   if (!tp_channel_close_finish (channel, result, &error))
     {
-      g_debug ("Failed to close tube channel: %s", error->message);
+      g_message ("Failed to close tube channel: %s", error->message);
       g_error_free (error);
       return;
     }
 
-  g_debug ("Tube channel closed");
+  g_message ("Tube channel closed");
 }
 
 static void
@@ -25,7 +27,7 @@ tube_conn_closed_cb (TpStreamTubeConnection *conn,
     const GError *error,
     gpointer user_data)
 {
-  g_debug ("Tube connection has been closed: %s", error->message);
+  g_message ("Tube connection has been closed: %s", error->message);
 }
 
 static void
@@ -45,7 +47,7 @@ _incoming_iostream (TpStreamTubeChannel *tube,
 
   contact = tp_stream_tube_connection_get_contact (tube_conn);
 
-  g_debug ("Got IOStream from %s",
+  g_message ("Got IOStream from %s",
       tp_contact_get_identifier (contact));
 
   conn = tp_stream_tube_connection_get_socket_connection (tube_conn);
@@ -56,9 +58,9 @@ _incoming_iostream (TpStreamTubeChannel *tube,
   /* this bit is not a good example */
   g_input_stream_read (in, &buf, sizeof (buf), NULL, &error);
   g_assert_no_error (error);
-  g_debug ("Received: %s", buf);
+  g_message ("Received: %s", buf);
 
-  g_debug ("Sending: Pong");
+  g_message ("Sending: Pong");
   g_output_stream_write (out, "Pong\n", 5, NULL, &error);
   g_assert_no_error (error);
 
@@ -76,13 +78,13 @@ _tube_offered (GObject *tube,
 
   if (!tp_stream_tube_channel_offer_finish (TP_STREAM_TUBE_CHANNEL (tube), res, &error))
     {
-      g_debug ("Failed to offer tube: %s", error->message);
+      g_message ("Failed to offer tube: %s", error->message);
 
       g_error_free (error);
       return;
     }
 
-  g_debug ("Tube offered");
+  g_message ("Tube offered");
 }
 
 static void
@@ -92,7 +94,7 @@ tube_invalidated_cb (TpStreamTubeChannel *tube,
     gchar *message,
     gpointer user_data)
 {
-  g_debug ("Tube has been invalidated: %s", message);
+  g_message ("Tube has been invalidated: %s", message);
   g_main_loop_quit (loop);
 }
 
@@ -109,13 +111,13 @@ _channel_created (GObject *source,
       TP_ACCOUNT_CHANNEL_REQUEST (source), result, NULL, &error);
   if (channel == NULL)
     {
-      g_debug ("Failed to create channel: %s", error->message);
+      g_message ("Failed to create channel: %s", error->message);
 
       g_error_free (error);
       return;
     }
 
-  g_debug ("Channel created: %s", tp_proxy_get_object_path (channel));
+  g_message ("Channel created: %s", tp_proxy_get_object_path (channel));
 
   tube = TP_STREAM_TUBE_CHANNEL (channel);
 
@@ -131,22 +133,26 @@ int
 main (int argc,
     const char **argv)
 {
-  TpDBusDaemon *dbus;
+  TpSimpleClientFactory *factory;
   TpAccount *account;
   char *account_path;
   GError *error = NULL;
   TpAccountChannelRequest *req;
   GHashTable *request;
 
-  g_assert (argc == 3);
+  if (argc != 3)
+    {
+      g_printerr ("Usage: offerer gabble/jabber/ladygaga t-pain@example.com\n");
+      return 2;
+    }
 
   g_type_init ();
 
-  dbus = tp_dbus_daemon_dup (&error);
-  g_assert_no_error (error);
+  factory = TP_SIMPLE_CLIENT_FACTORY (tp_automatic_client_factory_new (NULL));
 
   account_path = g_strconcat (TP_ACCOUNT_OBJECT_PATH_BASE, argv[1], NULL);
-  account = tp_account_new (dbus, account_path, &error);
+  account = tp_simple_client_factory_ensure_account (factory, account_path,
+      NULL, &error);
   g_assert_no_error (error);
   g_free (account_path);
 
@@ -169,7 +175,7 @@ main (int argc,
 
       NULL);
 
-  g_debug ("Offer channel to %s", argv[2]);
+  g_message ("Offer channel to %s", argv[2]);
 
   req = tp_account_channel_request_new (account, request,
       TP_USER_ACTION_TIME_CURRENT_TIME);
@@ -184,6 +190,7 @@ main (int argc,
   g_object_unref (req);
   g_hash_table_unref (request);
   g_main_loop_unref (loop);
+  g_object_unref (factory);
 
   return 0;
 }
