@@ -16,8 +16,6 @@
 #include <dbus/dbus-glib.h>
 
 #include <telepathy-glib/telepathy-glib.h>
-#include <telepathy-glib/handle-repo-dynamic.h>
-#include <telepathy-glib/handle-repo-static.h>
 
 #include "contact-list.h"
 #include "protocol.h"
@@ -151,7 +149,7 @@ example_contact_list_normalize_contact (TpHandleRepoIface *repo,
 
 static void
 create_handle_repos (TpBaseConnection *conn,
-                     TpHandleRepoIface *repos[NUM_TP_HANDLE_TYPES])
+                     TpHandleRepoIface *repos[TP_NUM_HANDLE_TYPES])
 {
   repos[TP_HANDLE_TYPE_CONTACT] = tp_dynamic_handle_repo_new
       (TP_HANDLE_TYPE_CONTACT, example_contact_list_normalize_contact, NULL);
@@ -192,7 +190,7 @@ presence_updated_cb (ExampleContactList *contact_list,
   TpPresenceStatus *status;
 
   /* we ignore the presence indicated by the contact list for our own handle */
-  if (contact == base->self_handle)
+  if (contact == tp_base_connection_get_self_handle (base))
     return;
 
   status = tp_presence_status_new (
@@ -233,17 +231,20 @@ start_connecting (TpBaseConnection *conn,
   ExampleContactListConnection *self = EXAMPLE_CONTACT_LIST_CONNECTION (conn);
   TpHandleRepoIface *contact_repo = tp_base_connection_get_handles (conn,
       TP_HANDLE_TYPE_CONTACT);
+  TpHandle self_handle;
 
   /* In a real connection manager we'd ask the underlying implementation to
    * start connecting, then go to state CONNECTED when finished, but here
    * we can do it immediately. */
 
-  conn->self_handle = tp_handle_ensure (contact_repo, self->priv->account,
+  self_handle = tp_handle_ensure (contact_repo, self->priv->account,
       NULL, error);
 
-  if (conn->self_handle == 0)
+  if (self_handle == 0)
     return FALSE;
 
+  tp_base_connection_set_self_handle (conn, self_handle);
+
   tp_base_connection_change_status (conn, TP_CONNECTION_STATUS_CONNECTED,
       TP_CONNECTION_STATUS_REASON_REQUESTED);
 
@@ -311,10 +312,7 @@ status_available (GObject *object,
 {
   TpBaseConnection *base = TP_BASE_CONNECTION (object);
 
-  if (base->status != TP_CONNECTION_STATUS_CONNECTED)
-    return FALSE;
-
-  return TRUE;
+  return tp_base_connection_check_connected (base, NULL);
 }
 
 static GHashTable *
@@ -337,7 +335,7 @@ get_contact_statuses (GObject *object,
 
       /* we get our own status from the connection, and everyone else's status
        * from the contact lists */
-      if (contact == base->self_handle)
+      if (contact == tp_base_connection_get_self_handle (base))
         {
           presence = (self->priv->away ? EXAMPLE_CONTACT_LIST_PRESENCE_AWAY
               : EXAMPLE_CONTACT_LIST_PRESENCE_AVAILABLE);
@@ -385,7 +383,8 @@ set_own_status (GObject *object,
 
   presences = g_hash_table_new_full (g_direct_hash, g_direct_equal,
       NULL, NULL);
-  g_hash_table_insert (presences, GUINT_TO_POINTER (base->self_handle),
+  g_hash_table_insert (presences,
+      GUINT_TO_POINTER (tp_base_connection_get_self_handle (base)),
       (gpointer) status);
   tp_presence_mixin_emit_presence_update (object, presences);
   g_hash_table_unref (presences);
@@ -411,6 +410,22 @@ example_contact_list_connection_get_possible_interfaces (void)
   return interfaces_always_present;
 }
 
+static GPtrArray *
+get_interfaces_always_present (TpBaseConnection *base)
+{
+  GPtrArray *interfaces;
+  guint i;
+
+  interfaces = TP_BASE_CONNECTION_CLASS (
+      example_contact_list_connection_parent_class)->get_interfaces_always_present (
+          base);
+
+  for (i = 0; interfaces_always_present[i] != NULL; i++)
+    g_ptr_array_add (interfaces, (gchar *) interfaces_always_present[i]);
+
+  return interfaces;
+}
+
 static void
 example_contact_list_connection_class_init (
     ExampleContactListConnectionClass *klass)
@@ -431,7 +446,7 @@ example_contact_list_connection_class_init (
   base_class->create_channel_managers = create_channel_managers;
   base_class->start_connecting = start_connecting;
   base_class->shut_down = shut_down;
-  base_class->interfaces_always_present = interfaces_always_present;
+  base_class->get_interfaces_always_present = get_interfaces_always_present;
 
   param_spec = g_param_spec_string ("account", "Account name",
       "The username of this user", NULL,
