@@ -36,6 +36,9 @@
  * has to be re-handled. This can be useful for example to move its window
  * to the foreground, if applicable.
  *
+ * Using this object is appropriate for most channel types.
+ * For a contact search channel, use tp_contact_search_new_async() instead.
+ *
  * Since: 0.11.12
  */
 
@@ -79,9 +82,11 @@
 #include <telepathy-glib/channel-request.h>
 #include <telepathy-glib/channel.h>
 #include <telepathy-glib/gtypes.h>
+#include <telepathy-glib/interfaces.h>
 #include <telepathy-glib/simple-handler.h>
 #include <telepathy-glib/util.h>
 #include <telepathy-glib/util-internal.h>
+#include <telepathy-glib/variant-util-internal.h>
 
 #define DEBUG_FLAG TP_DEBUG_CLIENT
 #include "telepathy-glib/debug-internal.h"
@@ -105,6 +110,7 @@ G_DEFINE_TYPE(TpAccountChannelRequest,
 enum {
     PROP_ACCOUNT = 1,
     PROP_REQUEST,
+    PROP_REQUEST_VARDICT,
     PROP_USER_ACTION_TIME,
     PROP_CHANNEL_REQUEST,
     N_PROPS
@@ -127,6 +133,10 @@ typedef enum
 struct _TpAccountChannelRequestPrivate
 {
   TpAccount *account;
+  /* dup'd string => slice-allocated GValue
+   *
+   * Do not use tp_asv_new() and friends, because they expect static
+   * string keys. */
   GHashTable *request;
   gint64 user_action_time;
 
@@ -235,6 +245,11 @@ tp_account_channel_request_get_property (GObject *object,
         g_value_set_boxed (value, self->priv->request);
         break;
 
+      case PROP_REQUEST_VARDICT:
+        g_value_take_variant (value,
+            tp_account_channel_request_dup_request (self));
+        break;
+
       case PROP_USER_ACTION_TIME:
         g_value_set_int64 (value, self->priv->user_action_time);
         break;
@@ -265,7 +280,45 @@ tp_account_channel_request_set_property (GObject *object,
         break;
 
       case PROP_REQUEST:
-        self->priv->request = g_value_dup_boxed (value);
+        /* If this property remains unset, GObject will set it to a NULL
+         * value. Ignore that, so request-vardict can be set instead. */
+        if (g_value_get_boxed (value) == NULL)
+          return;
+
+        /* Construct-only and mutually exclusive with request-vardict */
+        g_return_if_fail (self->priv->request == NULL);
+
+        /* We do not use tp_asv_new() and friends, because in principle,
+         * the request can contain user-defined keys. */
+        self->priv->request = g_hash_table_new_full (g_str_hash, g_str_equal,
+            g_free, (GDestroyNotify) tp_g_value_slice_free);
+        tp_g_hash_table_update (self->priv->request,
+            g_value_get_boxed (value),
+            (GBoxedCopyFunc) g_strdup,
+            (GBoxedCopyFunc) tp_g_value_slice_dup);
+        break;
+
+      case PROP_REQUEST_VARDICT:
+          {
+            GHashTable *hash;
+
+            /* If this property remains unset, GObject will set it to a NULL
+             * value. Ignore that, so request can be set instead. */
+            if (g_value_get_variant (value) == NULL)
+              return;
+
+            /* Construct-only and mutually exclusive with request */
+            g_return_if_fail (self->priv->request == NULL);
+
+            hash = _tp_asv_from_vardict (g_value_get_variant (value));
+            self->priv->request = g_hash_table_new_full (g_str_hash,
+                g_str_equal, g_free, (GDestroyNotify) tp_g_value_slice_free);
+
+            tp_g_hash_table_update (self->priv->request,
+                hash, (GBoxedCopyFunc) g_strdup,
+                (GBoxedCopyFunc) tp_g_value_slice_dup);
+            g_hash_table_unref (hash);
+          }
         break;
 
       case PROP_USER_ACTION_TIME:
@@ -334,7 +387,10 @@ tp_account_channel_request_class_init (
    * The desired D-Bus properties for the channel, represented as a
    * #GHashTable where the keys are strings and the values are #GValue.
    *
-   * This property can't be %NULL.
+   * When constructing a new object, one of
+   * #TpAccountChannelRequest:request or
+   * #TpAccountChannelRequest:request-vardict must be set to a non-%NULL
+   * value, and the other must remain unspecified.
    *
    * Since: 0.11.12
    */
@@ -345,6 +401,25 @@ tp_account_channel_request_class_init (
   g_object_class_install_property (object_class, PROP_REQUEST,
       param_spec);
 
+  /**
+   * TpAccountChannelRequest:request-vardict:
+   *
+   * The desired D-Bus properties for the channel.
+   *
+   * When constructing a new object, one of
+   * #TpAccountChannelRequest:request or
+   * #TpAccountChannelRequest:request-vardict must be set to a non-%NULL
+   * value, and the other must remain unspecified.
+   *
+   * Since: 0.19.10
+   */
+  param_spec = g_param_spec_variant ("request-vardict", "Request",
+      "A dictionary containing desirable properties for the channel",
+      G_VARIANT_TYPE_VARDICT, NULL,
+      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
+  g_object_class_install_property (object_class, PROP_REQUEST_VARDICT,
+      param_spec);
+
   /**
    * TpAccountChannelRequest:user-action-time:
    *
@@ -363,7 +438,7 @@ tp_account_channel_request_class_init (
    * user action happened at the current time, e.g. a client may
    * request that its window gains focus.
    *
-   * On X11-based systems, Gdk 2.x, Clutter 1.0 etc.,
+   * On X11-based systems, GDK 2, GDK 3, Clutter 1.0 etc.,
    * tp_user_action_time_from_x11() can be used to convert an X11 timestamp to
    * a Telepathy user action time.
    *
@@ -476,6 +551,51 @@ tp_account_channel_request_new (
       NULL);
 }
 
+/**
+ * tp_account_channel_request_new_vardict:
+ * @account: a #TpAccount
+ * @request: the requested
+ *  properties of the channel (see #TpAccountChannelRequest:request)
+ *  as a %G_VARIANT_TYPE_VARDICT
+ * @user_action_time: the time of the user action that caused this request,
+ *  or one of the special values %TP_USER_ACTION_TIME_NOT_USER_ACTION or
+ *  %TP_USER_ACTION_TIME_CURRENT_TIME (see
+ *  #TpAccountChannelRequest:user-action-time)
+ *
+ * Convenience function to create a new #TpAccountChannelRequest object.
+ *
+ * If @request is a floating reference, this function will
+ * take ownership of it, much like g_variant_ref_sink(). See documentation of
+ * that function for details.
+ *
+ * Returns: a new #TpAccountChannelRequest object
+ *
+ * Since: 0.19.10
+ */
+TpAccountChannelRequest *
+tp_account_channel_request_new_vardict (
+    TpAccount *account,
+    GVariant *request,
+    gint64 user_action_time)
+{
+  TpAccountChannelRequest *ret;
+
+  g_return_val_if_fail (TP_IS_ACCOUNT (account), NULL);
+  g_return_val_if_fail (request != NULL, NULL);
+  g_return_val_if_fail (g_variant_is_of_type (request, G_VARIANT_TYPE_VARDICT),
+      NULL);
+
+  g_variant_ref_sink (request);
+
+  ret = g_object_new (TP_TYPE_ACCOUNT_CHANNEL_REQUEST,
+      "account", account,
+      "request-vardict", request,
+      "user-action-time", user_action_time,
+      NULL);
+  g_variant_unref (request);
+  return ret;
+}
+
 /**
  * tp_account_channel_request_get_account:
  * @self: a #TpAccountChannelRequest
@@ -510,6 +630,27 @@ tp_account_channel_request_get_request (
   return self->priv->request;
 }
 
+/**
+ * tp_account_channel_request_dup_request:
+ * @self: a #TpAccountChannelRequest
+ *
+ * Return the #TpAccountChannelRequest:request-vardict construct-only
+ * property.
+ *
+ * Returns: (transfer full): the value of
+ *  #TpAccountChannelRequest:request-vardict
+ *
+ * Since: 0.19.10
+ */
+GVariant *
+tp_account_channel_request_dup_request (
+    TpAccountChannelRequest *self)
+{
+  g_return_val_if_fail (TP_IS_ACCOUNT_CHANNEL_REQUEST (self), NULL);
+
+  return _tp_asv_to_vardict (self->priv->request);
+}
+
 /**
  * tp_account_channel_request_get_user_action_time:
  * @self: a #TpAccountChannelRequest
@@ -534,7 +675,7 @@ complete_result (TpAccountChannelRequest *self)
 
   request_disconnect (self);
 
-  g_simple_async_result_complete (self->priv->result);
+  g_simple_async_result_complete_in_idle (self->priv->result);
 
   tp_clear_object (&self->priv->result);
 }
@@ -585,7 +726,7 @@ handle_channels (TpSimpleHandler *handler,
 
   if (G_UNLIKELY (g_list_length (channels) != 1))
     {
-      GError error = { TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+      GError error = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
           "We are supposed to handle only one channel" };
 
       tp_handle_channels_context_fail (context, &error);
@@ -695,7 +836,7 @@ acr_channel_request_succeeded_with_channel (TpChannelRequest *chan_req,
   /* ChannelRequest succeeded */
   if (self->priv->action_type == ACTION_TYPE_HANDLE)
     {
-      GError err = { TP_ERRORS, TP_ERROR_NOT_YOURS,
+      GError err = { TP_ERROR, TP_ERROR_NOT_YOURS,
           "Another Handler is handling this channel" };
 
       if (self->priv->result == NULL)
@@ -712,7 +853,7 @@ acr_channel_request_succeeded_with_channel (TpChannelRequest *chan_req,
 
       if (self->priv->channel == NULL)
         {
-          GError err = { TP_ERRORS, TP_ERROR_CONFUSED,
+          GError err = { TP_ERROR, TP_ERROR_CONFUSED,
               "Channel has been created but MC didn't give it back to us" };
 
           DEBUG ("%s", err.message);
@@ -1603,6 +1744,42 @@ tp_account_channel_request_ensure_and_observe_channel_finish (
       g_object_ref);
 }
 
+/**
+ * tp_account_channel_request_set_hint:
+ * @self: a #TpAccountChannelRequest
+ * @key: the key used for the hint
+ * @value: (transfer none): a variant containting the hint value
+ *
+ * Set additional information about the channel request, which will be used
+ * in the resulting request's #TpChannelRequest:hints property.
+ *
+ * This function can't be called once @self has been used to request a
+ * channel.
+ *
+ * Since: 0.19.8
+ */
+void
+tp_account_channel_request_set_hint (TpAccountChannelRequest *self,
+    const gchar *key,
+    GVariant *value)
+{
+  GValue one = G_VALUE_INIT, *two;
+
+  g_return_if_fail (!self->priv->requested);
+  g_return_if_fail (key != NULL);
+  g_return_if_fail (value != NULL);
+
+  if (self->priv->hints == NULL)
+    self->priv->hints = tp_asv_new (NULL, NULL);
+
+  dbus_g_value_parse_g_variant (value, &one);
+  two = tp_g_value_slice_dup (&one);
+
+  g_hash_table_insert (self->priv->hints, g_strdup (key), two);
+
+  g_value_unset (&one);
+}
+
 /**
  * tp_account_channel_request_set_hints:
  * @self: a #TpAccountChannelRequest
@@ -1614,6 +1791,9 @@ tp_account_channel_request_ensure_and_observe_channel_finish (
  * This function can't be called once @self has been used to request a
  * channel.
  *
+ * In high-level language bindings, use tp_account_channel_request_set_hint()
+ * instead.
+ *
  * Since: 0.13.14
  */
 void
@@ -1707,3 +1887,506 @@ _tp_account_channel_request_get_client (TpAccountChannelRequest *self)
 
   return self->priv->handler;
 }
+
+/**
+ * tp_account_channel_request_set_target_contact:
+ * @self: a #TpAccountChannelRequest
+ * @contact: the contact to be contacted
+ *
+ * Configure this request to create a peer-to-peer channel with @contact as
+ * the other peer.
+ *
+ * This function can't be called once @self has been used to request a
+ * channel.
+ *
+ * Since: 0.19.0
+ */
+void
+tp_account_channel_request_set_target_contact (
+    TpAccountChannelRequest *self,
+    TpContact *contact)
+{
+  g_return_if_fail (TP_IS_ACCOUNT_CHANNEL_REQUEST (self));
+  g_return_if_fail (TP_IS_CONTACT (contact));
+  g_return_if_fail (!self->priv->requested);
+
+  /* Do not use tp_asv_set_uint32 or similar - the key is dup'd */
+  g_hash_table_insert (self->priv->request,
+      g_strdup (TP_PROP_CHANNEL_TARGET_HANDLE_TYPE),
+      tp_g_value_slice_new_uint (TP_HANDLE_TYPE_CONTACT));
+  /* We use the ID because it persists across a disconnect/reconnect */
+  g_hash_table_insert (self->priv->request,
+      g_strdup (TP_PROP_CHANNEL_TARGET_ID),
+      tp_g_value_slice_new_string (tp_contact_get_identifier (contact)));
+}
+
+/**
+ * tp_account_channel_request_set_target_id:
+ * @self: a #TpAccountChannelRequest
+ * @handle_type: the type of @identifier, typically %TP_HANDLE_TYPE_CONTACT
+ *  or %TP_HANDLE_TYPE_ROOM
+ * @identifier: the unique identifier of the contact, room etc. to be
+ *  contacted
+ *
+ * Configure this request to create a channel with @identifier,
+ * an identifier of type @handle_type.
+ *
+ * This function can't be called once @self has been used to request a
+ * channel.
+ *
+ * Since: 0.19.0
+ */
+void
+tp_account_channel_request_set_target_id (
+    TpAccountChannelRequest *self,
+    TpHandleType handle_type,
+    const gchar *identifier)
+{
+  g_return_if_fail (TP_IS_ACCOUNT_CHANNEL_REQUEST (self));
+  g_return_if_fail (identifier != NULL);
+  g_return_if_fail (handle_type != TP_HANDLE_TYPE_NONE);
+  g_return_if_fail (!self->priv->requested);
+
+  /* Do not use tp_asv_set_uint32 or similar - the key is dup'd */
+  g_hash_table_insert (self->priv->request,
+      g_strdup (TP_PROP_CHANNEL_TARGET_HANDLE_TYPE),
+      tp_g_value_slice_new_uint (handle_type));
+  g_hash_table_insert (self->priv->request,
+      g_strdup (TP_PROP_CHANNEL_TARGET_ID),
+      tp_g_value_slice_new_string (identifier));
+}
+
+/**
+ * tp_account_channel_request_new_text:
+ * @account: a #TpAccount
+ * @user_action_time: the time of the user action that caused this request,
+ *  or one of the special values %TP_USER_ACTION_TIME_NOT_USER_ACTION or
+ *  %TP_USER_ACTION_TIME_CURRENT_TIME (see
+ *  #TpAccountChannelRequest:user-action-time)
+ *
+ * Convenience function to create a new #TpAccountChannelRequest object
+ * which will yield a Text channel.
+ *
+ * After creating the request, you will also need to set the "target"
+ * of the channel by calling one of the following functions:
+ *
+ * - tp_account_channel_request_set_target_contact()
+ * - tp_account_channel_request_set_target_id()
+ *
+ * Returns: a new #TpAccountChannelRequest object
+ *
+ * Since: 0.19.0
+ */
+TpAccountChannelRequest *
+tp_account_channel_request_new_text (
+    TpAccount *account,
+    gint64 user_action_time)
+{
+  TpAccountChannelRequest *self;
+  GHashTable *request;
+
+  g_return_val_if_fail (TP_IS_ACCOUNT (account), NULL);
+
+  request = tp_asv_new (
+      TP_PROP_CHANNEL_CHANNEL_TYPE, G_TYPE_STRING, TP_IFACE_CHANNEL_TYPE_TEXT,
+      NULL);
+
+  self = g_object_new (TP_TYPE_ACCOUNT_CHANNEL_REQUEST,
+      "account", account,
+      "request", request,
+      "user-action-time", user_action_time,
+      NULL);
+  g_hash_table_unref (request);
+  return self;
+}
+
+/**
+ * tp_account_channel_request_set_request_property:
+ * @self: a #TpAccountChannelRequest
+ * @name: a D-Bus property name
+ * @value: an arbitrary value for the property
+ *
+ * Configure this channel request to include the given property, as
+ * documented in the Telepathy D-Bus API Specification or an
+ * implementation-specific extension.
+ *
+ * Using this method is not recommended, but it can be necessary for
+ * experimental or implementation-specific interfaces.
+ *
+ * If the property is not supported by the protocol or channel type, the
+ * channel request will fail. Use #TpCapabilities and the Telepathy
+ * D-Bus API Specification to determine which properties are available.
+ *
+ * If @value is a floating reference, this method takes ownership of it
+ * by using g_variant_ref_sink(). This allows convenient inline use of
+ * #GVariant constructors:
+ *
+ * |[
+ * tp_account_channel_request_set_request_property (acr, "com.example.Int",
+ *     g_variant_new_int32 (17));
+ * tp_account_channel_request_set_request_property (acr, "com.example.String",
+ *     g_variant_new_string ("ferret"));
+ * ]|
+ *
+ * It is an error to provide a @value which contains types not supported by
+ * D-Bus.
+ *
+ * This function can't be called once @self has been used to request a
+ * channel.
+ *
+ * Since: 0.19.0
+ */
+void
+tp_account_channel_request_set_request_property (
+    TpAccountChannelRequest *self,
+    const gchar *name,
+    GVariant *value)
+{
+  GValue *v;
+
+  g_return_if_fail (TP_IS_ACCOUNT_CHANNEL_REQUEST (self));
+  g_return_if_fail (!self->priv->requested);
+
+  v = g_slice_new0 (GValue);
+  dbus_g_value_parse_g_variant (value, v);
+
+  g_hash_table_insert (self->priv->request, g_strdup (name), v);
+}
+
+/**
+ * tp_account_channel_request_new_audio_call:
+ * @account: a #TpAccount
+ * @user_action_time: the time of the user action that caused this request,
+ *  or one of the special values %TP_USER_ACTION_TIME_NOT_USER_ACTION or
+ *  %TP_USER_ACTION_TIME_CURRENT_TIME (see
+ *  #TpAccountChannelRequest:user-action-time)
+ *
+ * Convenience function to create a new #TpAccountChannelRequest object
+ * which will yield a Call channel, initially carrying audio only.
+ *
+ * After creating the request, you will usually also need to set the "target"
+ * of the channel by calling one of the following functions:
+ *
+ * - tp_account_channel_request_set_target_contact()
+ * - tp_account_channel_request_set_target_id()
+ *
+ * To call a contact, either use
+ * tp_account_channel_request_set_target_contact() or one of the generic
+ * methods that takes a handle type argument. To check whether this
+ * is possible, use tp_capabilities_supports_audio_call() with
+ * @handle_type set to %TP_HANDLE_TYPE_CONTACT.
+ *
+ * <!-- reinstate this when we have CMs that actually allow it:
+ * In some protocols it is possible to create a conference call which
+ * takes place in a named chatroom, by calling
+ * tp_account_channel_request_set_target_id() with @handle_type
+ * set to %TP_HANDLE_TYPE_ROOM. To test whether this is possible, use
+ * tp_capabilities_supports_audio_call() with @handle_type set to
+ * %TP_HANDLE_TYPE_ROOM.
+ * -->
+ *
+ * In some protocols, it is possible to create a Call channel without
+ * setting a target at all, which will result in a new, empty
+ * conference call. To test whether this is possible, use
+ * tp_capabilities_supports_audio_call() with @handle_type set to
+ * %TP_HANDLE_TYPE_NONE.
+ *
+ * Returns: a new #TpAccountChannelRequest object
+ *
+ * Since: 0.19.0
+ */
+TpAccountChannelRequest *
+tp_account_channel_request_new_audio_call (
+    TpAccount *account,
+    gint64 user_action_time)
+{
+  TpAccountChannelRequest *self;
+  GHashTable *request;
+
+  g_return_val_if_fail (TP_IS_ACCOUNT (account), NULL);
+
+  request = tp_asv_new (
+      TP_PROP_CHANNEL_CHANNEL_TYPE, G_TYPE_STRING, TP_IFACE_CHANNEL_TYPE_CALL,
+      TP_PROP_CHANNEL_TYPE_CALL_INITIAL_AUDIO, G_TYPE_BOOLEAN, TRUE,
+      NULL);
+
+  self = g_object_new (TP_TYPE_ACCOUNT_CHANNEL_REQUEST,
+      "account", account,
+      "request", request,
+      "user-action-time", user_action_time,
+      NULL);
+  g_hash_table_unref (request);
+  return self;
+}
+
+/**
+ * tp_account_channel_request_new_audio_video_call:
+ * @account: a #TpAccount
+ * @user_action_time: the time of the user action that caused this request,
+ *  or one of the special values %TP_USER_ACTION_TIME_NOT_USER_ACTION or
+ *  %TP_USER_ACTION_TIME_CURRENT_TIME (see
+ *  #TpAccountChannelRequest:user-action-time)
+ *
+ * Convenience function to create a new #TpAccountChannelRequest object
+ * which will yield a Call channel, initially carrying both audio
+ * and video.
+ *
+ * This is the same as tp_account_channel_request_new_audio_call(),
+ * except that the channel will initially carry video as well as audio,
+ * and instead of using tp_capabilities_supports_audio_call()
+ * you should test capabilities with
+ * tp_capabilities_supports_audio_video_call().
+ *
+ * See the documentation of tp_account_channel_request_new_audio_call()
+ * for details of how to set the target (contact, chatroom etc.) for the call.
+ *
+ * Returns: a new #TpAccountChannelRequest object
+ *
+ * Since: 0.19.0
+ */
+TpAccountChannelRequest *
+tp_account_channel_request_new_audio_video_call (
+    TpAccount *account,
+    gint64 user_action_time)
+{
+  TpAccountChannelRequest *self;
+  GHashTable *request;
+
+  g_return_val_if_fail (TP_IS_ACCOUNT (account), NULL);
+
+  request = tp_asv_new (
+      TP_PROP_CHANNEL_CHANNEL_TYPE, G_TYPE_STRING, TP_IFACE_CHANNEL_TYPE_CALL,
+      TP_PROP_CHANNEL_TYPE_CALL_INITIAL_AUDIO, G_TYPE_BOOLEAN, TRUE,
+      TP_PROP_CHANNEL_TYPE_CALL_INITIAL_VIDEO, G_TYPE_BOOLEAN, TRUE,
+      NULL);
+
+  self = g_object_new (TP_TYPE_ACCOUNT_CHANNEL_REQUEST,
+      "account", account,
+      "request", request,
+      "user-action-time", user_action_time,
+      NULL);
+  g_hash_table_unref (request);
+  return self;
+}
+
+/**
+ * tp_account_channel_request_new_file_transfer:
+ * @account: a #TpAccount
+ * @filename: a suggested name for the file, which should not contain
+ *  directories or directory separators (for example, if you are sending
+ * a file called /home/user/monkey.pdf, set this to monkey.pdf)
+ * @mime_type: (allow-none): the MIME type (content-type) of the file;
+ *  a %NULL value is allowed, and is treated as
+ *  "application/octet-stream"
+ * @size: the file's size in bytes
+ * @user_action_time: the time of the user action that caused this request,
+ *  or one of the special values %TP_USER_ACTION_TIME_NOT_USER_ACTION or
+ *  %TP_USER_ACTION_TIME_CURRENT_TIME (see
+ *  #TpAccountChannelRequest:user-action-time)
+ *
+ * Convenience function to create a new #TpAccountChannelRequest object,
+ * which will yield a FileTransfer channel to send a file to a contact.
+ *
+ * After creating the request, you will also need to set the "target"
+ * of the channel by calling one of the following functions:
+ *
+ * - tp_account_channel_request_set_target_contact()
+ * - tp_account_channel_request_set_target_id()
+ *
+ * Returns: a new #TpAccountChannelRequest object
+ *
+ * Since: 0.19.0
+ */
+TpAccountChannelRequest *
+tp_account_channel_request_new_file_transfer (
+    TpAccount *account,
+    const gchar *filename,
+    const gchar *mime_type,
+    guint64 size,
+    gint64 user_action_time)
+{
+  TpAccountChannelRequest *self;
+  GHashTable *request;
+
+  g_return_val_if_fail (TP_IS_ACCOUNT (account), NULL);
+  g_return_val_if_fail (!tp_str_empty (filename), NULL);
+  g_return_val_if_fail (mime_type == NULL || mime_type[0] != '\0', NULL);
+
+  if (mime_type == NULL)
+    mime_type = "application/octet-stream";
+
+  request = tp_asv_new (
+      TP_PROP_CHANNEL_CHANNEL_TYPE, G_TYPE_STRING,
+          TP_IFACE_CHANNEL_TYPE_FILE_TRANSFER,
+      TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_FILENAME, G_TYPE_STRING, filename,
+      TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_CONTENT_TYPE, G_TYPE_STRING, mime_type,
+      TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_SIZE, G_TYPE_UINT64, size,
+      NULL);
+
+  self = g_object_new (TP_TYPE_ACCOUNT_CHANNEL_REQUEST,
+      "account", account,
+      "request", request,
+      "user-action-time", user_action_time,
+      NULL);
+  g_hash_table_unref (request);
+  return self;
+}
+
+/**
+ * tp_account_channel_request_set_file_transfer_description:
+ * @self: a #TpAccountChannelRequest
+ * @description: a description of the file
+ *
+ * Configure this channel request to provide the recipient of the file
+ * with the given description.
+ *
+ * If file descriptions are not supported by the protocol, or if this
+ * method is used on a request that is not actually a file transfer, the
+ * channel request will fail. Use
+ * tp_capabilities_supports_file_transfer_description() to determine
+ * whether outgoing file transfers can have a description.
+ *
+ * This function can't be called once @self has been used to request a
+ * channel.
+ *
+ * Since: 0.19.0
+ */
+void
+tp_account_channel_request_set_file_transfer_description (
+    TpAccountChannelRequest *self,
+    const gchar *description)
+{
+  g_return_if_fail (TP_IS_ACCOUNT_CHANNEL_REQUEST (self));
+  g_return_if_fail (!self->priv->requested);
+  g_return_if_fail (description != NULL);
+
+  g_hash_table_insert (self->priv->request,
+      g_strdup (TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_DESCRIPTION),
+      tp_g_value_slice_new_string (description));
+}
+
+/**
+ * tp_account_channel_request_set_file_transfer_uri:
+ * @self: a #TpAccountChannelRequest
+ * @uri: the source URI for the file
+ *
+ * Configure this channel request to provide other local Telepathy
+ * components with the URI of the file being sent. Unlike most
+ * properties on a file transfer channel, this information is not
+ * sent to the recipient of the file; instead, it is signalled on
+ * D-Bus for use by other Telepathy components.
+ *
+ * The URI should usually be a <code>file</code> URI as defined by
+ * <ulink url="http://www.apps.ietf.org/rfc/rfc1738.html#sec-3.10">RFC 1738
+ * §3.10</ulink> (for instance, <code>file:///path/to/file</code> or
+ * <code>file://localhost/path/to/file</code>). If a remote resource
+ * is being transferred to a contact, it may have a different scheme,
+ * such as <code>http</code>.
+ *
+ * Even if this method is used, the connection manager will not read
+ * the file from disk: the handler for the channel is still
+ * responsible for streaming the file. However, providing the URI
+ * allows a local logger to log which file was transferred, for instance.
+ *
+ * If this functionality is not supported by the connection manager, or
+ * if this method is used on a request that is not actually a file transfer,
+ * the channel request will fail. Use
+ * tp_capabilities_supports_file_transfer_uri() to determine
+ * whether outgoing file transfers can have a URI.
+ *
+ * This function can't be called once @self has been used to request a
+ * channel.
+ *
+ * Since: 0.19.0
+ */
+void
+tp_account_channel_request_set_file_transfer_uri (
+    TpAccountChannelRequest *self,
+    const gchar *uri)
+{
+  g_return_if_fail (TP_IS_ACCOUNT_CHANNEL_REQUEST (self));
+  g_return_if_fail (!self->priv->requested);
+  g_return_if_fail (uri != NULL);
+
+  g_hash_table_insert (self->priv->request,
+      g_strdup (TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_URI),
+      tp_g_value_slice_new_string (uri));
+}
+
+/**
+ * tp_account_channel_request_set_file_transfer_timestamp:
+ * @self: a #TpAccountChannelRequest
+ * @timestamp: the modification timestamp of the file, in seconds since the
+ *  Unix epoch (the beginning of 1970 in the UTC time zone), as returned
+ *  by g_date_time_to_unix()
+ *
+ * Configure this channel request to accompany the file transfer with
+ * the given modification timestamp for the file.
+ *
+ * If file timestamps are not supported by the protocol, or if this
+ * method is used on a request that is not actually a file transfer, the
+ * channel request will fail. Use
+ * tp_capabilities_supports_file_transfer_date() to determine
+ * whether outgoing file transfers can have a timestamp.
+ *
+ * This function can't be called once @self has been used to request a
+ * channel.
+ *
+ * Since: 0.19.0
+ */
+void
+tp_account_channel_request_set_file_transfer_timestamp (
+    TpAccountChannelRequest *self,
+    guint64 timestamp)
+{
+  g_return_if_fail (TP_IS_ACCOUNT_CHANNEL_REQUEST (self));
+  g_return_if_fail (!self->priv->requested);
+
+  g_hash_table_insert (self->priv->request,
+      g_strdup (TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_DATE),
+      tp_g_value_slice_new_uint64 (timestamp));
+}
+
+/**
+ * tp_account_channel_request_set_file_transfer_initial_offset:
+ * @self: a #TpAccountChannelRequest
+ * @offset: the offset into the file at which the transfer will start
+ *
+ * Configure this channel request to inform the recipient of the file
+ * that this channel will not send the first @offset bytes of the file.
+ * In some protocols, this can be used to resume an interrupted transfer.
+ *
+ * If this method is not called, the default is to start from the
+ * beginning of the file (equivalent to @offset = 0).
+ *
+ * If offsets greater than 0 are not supported by the protocol, or if this
+ * method is used on a request that is not actually a file transfer, the
+ * channel request will fail. Use
+ * tp_capabilities_supports_file_transfer_initial_offset() to determine
+ * whether offsets greater than 0 are available.
+ *
+ * This function can't be called once @self has been used to request a
+ * channel.
+ *
+ * Since: 0.19.0
+ */
+void
+tp_account_channel_request_set_file_transfer_initial_offset (
+    TpAccountChannelRequest *self,
+    guint64 offset)
+{
+  g_return_if_fail (TP_IS_ACCOUNT_CHANNEL_REQUEST (self));
+  g_return_if_fail (!self->priv->requested);
+
+  if (offset == 0)
+    {
+      g_hash_table_remove (self->priv->request,
+          TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_INITIAL_OFFSET);
+    }
+  else
+    {
+      g_hash_table_insert (self->priv->request,
+          g_strdup (TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_INITIAL_OFFSET),
+          tp_g_value_slice_new_uint64 (offset));
+    }
+}
