@@ -159,6 +159,7 @@ G_BEGIN_DECLS
 #define TP_VERSION_0_16 (_TP_ENCODE_VERSION (0, 16))
 #define TP_VERSION_0_18 (_TP_ENCODE_VERSION (0, 18))
 #define TP_VERSION_0_20 (_TP_ENCODE_VERSION (0, 20))
+#define TP_VERSION_0_22 (_TP_ENCODE_VERSION (0, 22))
 #define TP_VERSION_1_0 (_TP_ENCODE_VERSION (1, 0))
 
 #if (TP_MINOR_VERSION == 99)
@@ -220,6 +221,14 @@ G_BEGIN_DECLS
 # define _TP_DEPRECATED_IN_0_20_FOR(f) /* nothing */
 #endif
 
+#if TP_VERSION_MIN_REQUIRED >= TP_VERSION_0_22
+# define _TP_DEPRECATED_IN_0_22 _TP_DEPRECATED
+# define _TP_DEPRECATED_IN_0_22_FOR(f) _TP_DEPRECATED_FOR(f)
+#else
+# define _TP_DEPRECATED_IN_0_22 /* nothing */
+# define _TP_DEPRECATED_IN_0_22_FOR(f) /* nothing */
+#endif
+
 #if TP_VERSION_MIN_REQUIRED >= TP_VERSION_1_0
 # define _TP_DEPRECATED_IN_1_0 _TP_DEPRECATED
 # define _TP_DEPRECATED_IN_1_0_FOR(f) _TP_DEPRECATED_FOR(f)
@@ -254,6 +263,12 @@ G_BEGIN_DECLS
 # define _TP_AVAILABLE_IN_0_20 /* nothing */
 #endif
 
+#if TP_VERSION_MAX_ALLOWED < TP_VERSION_0_22
+# define _TP_AVAILABLE_IN_0_22 _TP_UNAVAILABLE(0, 22)
+#else
+# define _TP_AVAILABLE_IN_0_22 /* nothing */
+#endif
+
 #if TP_VERSION_MAX_ALLOWED < TP_VERSION_1_0
 # define _TP_AVAILABLE_IN_1_0 _TP_UNAVAILABLE(1, 0)
 #else
