@@ -31,6 +31,7 @@
 
 #include "config.h"
 
+#include <glib/gstdio.h>
 #include <gobject/gvaluecollector.h>
 
 #ifdef HAVE_GIO_UNIX
@@ -43,6 +44,7 @@
 #include <telepathy-glib/util-internal.h>
 #include <telepathy-glib/util.h>
 
+#include <errno.h>
 #include <stdio.h>
 #include <string.h>
 
@@ -111,7 +113,7 @@
  */
 
 /**
- * tp_g_ptr_array_contains:
+ * tp_g_ptr_array_contains: (skip)
  * @haystack: The pointer array to be searched
  * @needle: The pointer to look for
  *
@@ -144,7 +146,7 @@ add_to_array (gpointer data,
 }
 
 /**
- * tp_g_ptr_array_extend:
+ * tp_g_ptr_array_extend: (skip)
  * @target: a #GPtrArray to copy items to
  * @source: a #GPtrArray to copy items from
  *
@@ -170,7 +172,7 @@ tp_g_ptr_array_extend (GPtrArray *target,
 }
 
 /**
- * tp_g_value_slice_new:
+ * tp_g_value_slice_new: (skip)
  * @type: The type desired for the new GValue
  *
  * Slice-allocate an empty #GValue. tp_g_value_slice_new_boolean() and similar
@@ -190,7 +192,7 @@ tp_g_value_slice_new (GType type)
 }
 
 /**
- * tp_g_value_slice_new_boolean:
+ * tp_g_value_slice_new_boolean: (skip)
  * @b: a boolean value
  *
  * Slice-allocate and initialize a #GValue. This function is convenient to
@@ -211,7 +213,7 @@ tp_g_value_slice_new_boolean (gboolean b)
 }
 
 /**
- * tp_g_value_slice_new_int:
+ * tp_g_value_slice_new_int: (skip)
  * @n: an integer
  *
  * Slice-allocate and initialize a #GValue. This function is convenient to
@@ -232,7 +234,7 @@ tp_g_value_slice_new_int (gint n)
 }
 
 /**
- * tp_g_value_slice_new_int64:
+ * tp_g_value_slice_new_int64: (skip)
  * @n: a 64-bit integer
  *
  * Slice-allocate and initialize a #GValue. This function is convenient to
@@ -253,7 +255,7 @@ tp_g_value_slice_new_int64 (gint64 n)
 }
 
 /**
- * tp_g_value_slice_new_byte:
+ * tp_g_value_slice_new_byte: (skip)
  * @n: an unsigned integer
  *
  * Slice-allocate and initialize a #GValue. This function is convenient to
@@ -274,7 +276,7 @@ tp_g_value_slice_new_byte (guchar n)
 }
 
 /**
- * tp_g_value_slice_new_uint:
+ * tp_g_value_slice_new_uint: (skip)
  * @n: an unsigned integer
  *
  * Slice-allocate and initialize a #GValue. This function is convenient to
@@ -295,7 +297,7 @@ tp_g_value_slice_new_uint (guint n)
 }
 
 /**
- * tp_g_value_slice_new_uint64:
+ * tp_g_value_slice_new_uint64: (skip)
  * @n: a 64-bit unsigned integer
  *
  * Slice-allocate and initialize a #GValue. This function is convenient to
@@ -316,7 +318,7 @@ tp_g_value_slice_new_uint64 (guint64 n)
 }
 
 /**
- * tp_g_value_slice_new_double:
+ * tp_g_value_slice_new_double: (skip)
  * @d: a number
  *
  * Slice-allocate and initialize a #GValue. This function is convenient to
@@ -337,7 +339,7 @@ tp_g_value_slice_new_double (double n)
 }
 
 /**
- * tp_g_value_slice_new_string:
+ * tp_g_value_slice_new_string: (skip)
  * @string: a string to be copied into the value
  *
  * Slice-allocate and initialize a #GValue. This function is convenient to
@@ -358,7 +360,7 @@ tp_g_value_slice_new_string (const gchar *string)
 }
 
 /**
- * tp_g_value_slice_new_static_string:
+ * tp_g_value_slice_new_static_string: (skip)
  * @string: a static string which must remain valid forever, to be pointed to
  *  by the value
  *
@@ -380,7 +382,7 @@ tp_g_value_slice_new_static_string (const gchar *string)
 }
 
 /**
- * tp_g_value_slice_new_take_string:
+ * tp_g_value_slice_new_take_string: (skip)
  * @string: a string which will be freed with g_free() by the returned #GValue
  *  (the caller must own it before calling this function, but no longer owns
  *  it after this function returns)
@@ -403,7 +405,7 @@ tp_g_value_slice_new_take_string (gchar *string)
 }
 
 /**
- * tp_g_value_slice_new_boxed:
+ * tp_g_value_slice_new_boxed: (skip)
  * @type: a boxed type
  * @p: a pointer of type @type, which will be copied
  *
@@ -428,7 +430,7 @@ tp_g_value_slice_new_boxed (GType type,
 }
 
 /**
- * tp_g_value_slice_new_static_boxed:
+ * tp_g_value_slice_new_static_boxed: (skip)
  * @type: a boxed type
  * @p: a pointer of type @type, which must remain valid forever
  *
@@ -453,7 +455,7 @@ tp_g_value_slice_new_static_boxed (GType type,
 }
 
 /**
- * tp_g_value_slice_new_take_boxed:
+ * tp_g_value_slice_new_take_boxed: (skip)
  * @type: a boxed type
  * @p: a pointer of type @type which will be freed with g_boxed_free() by the
  *  returned #GValue (the caller must own it before calling this function, but
@@ -480,7 +482,7 @@ tp_g_value_slice_new_take_boxed (GType type,
 }
 
 /**
- * tp_g_value_slice_free:
+ * tp_g_value_slice_free: (skip)
  * @value: A GValue which was allocated with the g_slice API
  *
  * Unset and free a slice-allocated GValue.
@@ -498,7 +500,7 @@ tp_g_value_slice_free (GValue *value)
 
 
 /**
- * tp_g_value_slice_dup:
+ * tp_g_value_slice_dup: (skip)
  * @value: A GValue
  *
  * <!-- 'Returns' says it all -->
@@ -537,7 +539,7 @@ _tp_g_hash_table_update_helper (gpointer key,
 }
 
 /**
- * tp_g_hash_table_update:
+ * tp_g_hash_table_update: (skip)
  * @target: The hash table to be updated
  * @source: The hash table to update it with (read-only)
  * @key_dup: function to duplicate a key from @source so it can be be stored
@@ -568,7 +570,7 @@ tp_g_hash_table_update (GHashTable *target,
 }
 
 /**
- * tp_str_empty:
+ * tp_str_empty: (skip)
  * @s: (type utf8) (transfer none): a string
  *
  * Return %TRUE if @s is empty, counting %NULL as empty.
@@ -580,7 +582,7 @@ tp_g_hash_table_update (GHashTable *target,
 /* no definition here - it's inlined */
 
 /**
- * tp_strdiff:
+ * tp_strdiff: (skip)
  * @left: The first string to compare (may be NULL)
  * @right: The second string to compare (may be NULL)
  *
@@ -601,7 +603,7 @@ tp_strdiff (const gchar *left, const gchar *right)
 
 
 /**
- * tp_mixin_offset_cast:
+ * tp_mixin_offset_cast: (skip)
  * @instance: A pointer to a structure
  * @offset: The offset of a structure member in bytes, which must not be 0
  *
@@ -621,7 +623,7 @@ tp_mixin_offset_cast (gpointer instance, guint offset)
 
 
 /**
- * tp_mixin_instance_get_offset:
+ * tp_mixin_instance_get_offset: (skip)
  * @instance: A pointer to a GObject-derived instance structure
  * @quark: A quark that was used to store the offset with g_type_set_qdata()
  *
@@ -658,7 +660,7 @@ tp_mixin_instance_get_offset (gpointer instance,
 
 
 /**
- * tp_mixin_class_get_offset:
+ * tp_mixin_class_get_offset: (skip)
  * @klass: A pointer to a GObjectClass-derived class structure
  * @quark: A quark that was used to store the offset with g_type_set_qdata()
  *
@@ -724,7 +726,8 @@ _esc_ident_bad (gchar c, gboolean is_first)
  * smaller allowed set. As a special case, "" is escaped to "_" (just for
  * completeness, really).
  *
- * Returns: the escaped string, which must be freed by the caller with #g_free
+ * Returns: (transfer full): the escaped string, which must be freed by
+ *  the caller with #g_free
  */
 gchar *
 tp_escape_as_identifier (const gchar *name)
@@ -784,7 +787,7 @@ tp_escape_as_identifier (const gchar *name)
 
 
 /**
- * tp_strv_contains:
+ * tp_strv_contains: (skip)
  * @strv: a NULL-terminated array of strings, or %NULL (which is treated as an
  *        empty strv)
  * @str: a non-NULL string
@@ -814,7 +817,7 @@ tp_strv_contains (const gchar * const *strv,
 }
 
 /**
- * tp_g_key_file_get_int64:
+ * tp_g_key_file_get_int64: (skip)
  * @key_file: a non-%NULL #GKeyFile
  * @group_name: a non-%NULL group name
  * @key: a non-%NULL key
@@ -828,6 +831,7 @@ tp_strv_contains (const gchar * const *strv,
  * 0 if the key was not found or could not be parsed.
  *
  * Since: 0.7.31
+ * Deprecated: Since 0.21.0. Use g_key_file_get_int64() instead.
  */
 gint64
 tp_g_key_file_get_int64 (GKeyFile *key_file,
@@ -862,7 +866,7 @@ tp_g_key_file_get_int64 (GKeyFile *key_file,
 }
 
 /**
- * tp_g_key_file_get_uint64:
+ * tp_g_key_file_get_uint64: (skip)
  * @key_file: a non-%NULL #GKeyFile
  * @group_name: a non-%NULL group name
  * @key: a non-%NULL key
@@ -876,6 +880,7 @@ tp_g_key_file_get_int64 (GKeyFile *key_file,
  * or 0 if the key was not found or could not be parsed.
  *
  * Since: 0.7.31
+ * Deprecated: Since 0.21.0. Use g_key_file_get_uint64() instead.
  */
 guint64
 tp_g_key_file_get_uint64 (GKeyFile *key_file,
@@ -981,7 +986,7 @@ closure_invalidated_cb (gpointer ctx_,
 }
 
 /**
- * tp_g_signal_connect_object:
+ * tp_g_signal_connect_object: (skip)
  * @instance: the instance to connect to.
  * @detailed_signal: a string of the form "signal-name::detail".
  * @c_handler: the #GCallback to connect.
@@ -1072,7 +1077,7 @@ _tp_quark_array_copy (const GQuark *quarks)
 }
 
 /**
- * tp_value_array_build:
+ * tp_value_array_build: (skip)
  * @length: The number of elements that should be in the array
  * @type: The type of the first argument.
  * @...: The value of the first item in the struct followed by a list of type,
@@ -1138,7 +1143,7 @@ tp_value_array_build (gsize length,
 }
 
 /**
- * tp_value_array_unpack:
+ * tp_value_array_unpack: (skip)
  * @array: the array to unpack
  * @len: The number of elements that should be in the array
  * @...: a list of correctly typed pointers to store the values in
@@ -1222,7 +1227,7 @@ struct _TpWeakRef {
 };
 
 /**
- * tp_weak_ref_new:
+ * tp_weak_ref_new: (skip)
  * @object: (type GObject.Object): an object to which to take a weak reference
  * @user_data: optional additional data to store alongside the weak ref
  * @destroy: destructor for @user_data, called when the weak ref
@@ -1230,7 +1235,7 @@ struct _TpWeakRef {
  *
  * Return a new weak reference wrapper for @object.
  *
- * Returns: a new weak-reference wrapper
+ * Returns: (transfer full): a new weak-reference wrapper
  *
  * Free-function: tp_weak_ref_destroy()
  *
@@ -1254,7 +1259,7 @@ tp_weak_ref_new (gpointer object,
 }
 
 /**
- * tp_weak_ref_get_user_data:
+ * tp_weak_ref_get_user_data: (skip)
  * @self: a weak reference
  *
  * Return the additional data that was passed to tp_weak_ref_new().
@@ -1271,7 +1276,7 @@ tp_weak_ref_get_user_data (TpWeakRef *self)
 }
 
 /**
- * tp_weak_ref_dup_object:
+ * tp_weak_ref_dup_object: (skip)
  * @self: a weak reference
  *
  * If the weakly referenced object still exists, return a new reference to
@@ -1291,8 +1296,8 @@ tp_weak_ref_dup_object (TpWeakRef *self)
 }
 
 /**
- * tp_weak_ref_destroy:
- * @self: a weak reference
+ * tp_weak_ref_destroy: (skip)
+ * @self: (transfer full): a weak reference
  *
  * Free a weak reference wrapper. This drops the weak reference to the
  * object (if it still exists), and frees the user data with the user-supplied
@@ -1383,9 +1388,9 @@ tp_weak_ref_destroy (TpWeakRef *self)
 
 /**
  * tp_simple_async_report_success_in_idle:
- * @source: the source object
- * @callback: the callback
- * @user_data: user data for @callback
+ * @source: (allow-none): the source object
+ * @callback: (scope async): the callback
+ * @user_data: (closure): user data for @callback
  * @source_tag: the source tag for the #GSimpleAsyncResult
  *
  * Create a new #GSimpleAsyncResult with no operation result, and call
@@ -1419,7 +1424,7 @@ tp_simple_async_report_success_in_idle (GObject *source,
  *
  * Convert an X11 timestamp into a user action time as used in Telepathy.
  *
- * This also works for the timestamps used by Gdk 2.x and Clutter 1.0;
+ * This also works for the timestamps used by GDK 2, GDK 3 and Clutter 1.0;
  * it may or may not work with other toolkits or versions.
  *
  * Returns: a nonzero Telepathy user action time, or
@@ -1450,8 +1455,8 @@ tp_user_action_time_from_x11 (guint32 x11_time)
  * call gtk_window_present_with_time() using @x11_time as input, for instance.
  *
  * @x11_time is used to return a timestamp in the right format for X11,
- * Gdk 2.x and Clutter 1.0; it may or may not work with other toolkits or
- * versions.
+ * GDK 2, GDK 3 and Clutter 1.0; it may or may not work with other
+ * toolkits or versions.
  *
  * Returns: %TRUE if it would be appropriate to present a window
  *
@@ -1560,32 +1565,47 @@ _tp_quark_array_merge_valist (GArray *array,
 #ifdef HAVE_GIO_UNIX
 GSocketAddress *
 _tp_create_temp_unix_socket (GSocketService *service,
+    gchar **tmpdir,
     GError **error)
 {
-  guint i;
   GSocketAddress *address;
+  gchar *dir = g_dir_make_tmp ("tp-glib-socket.XXXXXX", error);
+  gchar *name;
 
-  /* why doesn't GIO provide a method to create a socket we don't
-   * care about? Iterate until we find a valid temporary name.
-   *
-   * Try a maximum of 10 times to get a socket */
-  for (i = 0; i < 10; i++)
+  if (dir == NULL)
+    return NULL;
+
+  if (g_chmod (dir, 0700) != 0)
     {
-      address = g_unix_socket_address_new (tmpnam (NULL));
+      int e = errno;
 
-      g_clear_error (error);
-
-      if (g_socket_listener_add_address (
-            G_SOCKET_LISTENER (service),
-            address, G_SOCKET_TYPE_STREAM,
-            G_SOCKET_PROTOCOL_DEFAULT,
-            NULL, NULL, error))
-        return address;
-      else
-        g_object_unref (address);
+      g_set_error (error, G_IO_ERROR, g_io_error_from_errno (e),
+          "unable to set permissions of %s to 0700: %s", dir,
+          g_strerror (e));
+      g_free (dir);
+      return NULL;
     }
 
-  return NULL;
+  name = g_build_filename (dir, "s", NULL);
+  address = g_unix_socket_address_new (name);
+  g_free (name);
+
+  if (!g_socket_listener_add_address (G_SOCKET_LISTENER (service),
+        address, G_SOCKET_TYPE_STREAM,
+        G_SOCKET_PROTOCOL_DEFAULT,
+        NULL, NULL, error))
+    {
+      g_object_unref (address);
+      g_free (dir);
+      return NULL;
+    }
+
+  if (tmpdir != NULL)
+    *tmpdir = dir;
+  else
+    g_free (dir);
+
+  return address;
 }
 #endif /* HAVE_GIO_UNIX */
 
@@ -1632,7 +1652,7 @@ _tp_create_channel_request_list (TpSimpleClientFactory *factory,
  * _g_utf8_make_valid<!-- -->() function, and will be deprecated as
  * soon as the glib one becomes public.
  *
- * Returns: a new valid UTF8 string
+ * Returns: (transfer full): a new valid UTF8 string
  *
  * Since: 0.13.15
  */
@@ -1744,6 +1764,32 @@ _tp_enum_to_nick (
     return NULL;
 }
 
+/*
+ * _tp_enum_to_nick_nonnull:
+ *
+ * The same as _tp_enum_to_nick, but always returns non-NULL.
+ */
+const gchar *
+_tp_enum_to_nick_nonnull (
+    GType enum_type,
+    gint value)
+{
+  GEnumClass *klass = g_type_class_ref (enum_type);
+  GEnumValue *enum_value;
+
+  g_return_val_if_fail (klass != NULL, "(incorrect class)");
+
+  enum_value = g_enum_get_value (klass, value);
+  g_type_class_unref (klass);
+
+  if (enum_value == NULL)
+    return "(out-of-range value)";
+  else if (enum_value->value_nick == NULL)
+    return "(value with no nickname)";
+  else
+    return enum_value->value_nick;
+}
+
 gboolean
 _tp_bind_connection_status_to_boolean (GBinding *binding,
     const GValue *src_value,
@@ -1766,18 +1812,6 @@ _tp_bind_connection_status_to_boolean (GBinding *binding,
   return TRUE;
 }
 
-GPtrArray *
-_tp_g_ptr_array_new_full (guint reserved_size,
-    GDestroyNotify element_free_func)
-{
-  GPtrArray *array;
-
-  array = g_ptr_array_sized_new (reserved_size);
-  g_ptr_array_set_free_func (array, element_free_func);
-
-  return array;
-}
-
 /*
  * _tp_determine_socket_address_type:
  *
@@ -1811,7 +1845,7 @@ _tp_determine_socket_address_type (GHashTable *supported_sockets,
     }
 
   /* This should never happen */
-  g_set_error (error, TP_ERRORS,
+  g_set_error (error, TP_ERROR,
       TP_ERROR_NOT_IMPLEMENTED, "No supported socket types");
 
   return FALSE;
@@ -1892,7 +1926,7 @@ _tp_determine_access_control_type (GHashTable *supported_sockets,
   /* This should never happen */
   if (!support_localhost)
     {
-      g_set_error (error, TP_ERRORS,
+      g_set_error (error, TP_ERROR,
           TP_ERROR_NOT_IMPLEMENTED, "No supported access control");
       return FALSE;
     }
@@ -2024,7 +2058,7 @@ _tp_contacts_from_values (GHashTable *table)
   if (table == NULL)
       return NULL;
 
-  contacts = _tp_g_ptr_array_new_full (g_hash_table_size (table),
+  contacts = g_ptr_array_new_full (g_hash_table_size (table),
       g_object_unref);
 
   g_hash_table_iter_init (&iter, table);
@@ -2049,11 +2083,7 @@ _tp_contacts_from_values (GHashTable *table)
 GList *
 _tp_object_list_copy (GList *l)
 {
-  GList *new_l;
-
-  new_l = g_list_copy (l);
-  g_list_foreach (new_l, (GFunc) g_object_ref, NULL);
-  return new_l;
+  return _tp_g_list_copy_deep (l, (GCopyFunc) g_object_ref, NULL);
 }
 
 /*
@@ -2069,3 +2099,22 @@ _tp_object_list_free (GList *l)
 {
   g_list_free_full (l, g_object_unref);
 }
+
+GList *
+_tp_g_list_copy_deep (GList *list,
+    GCopyFunc func,
+    gpointer user_data)
+{
+  GList *ret = NULL;
+  GList *l;
+
+  ret = g_list_copy (list);
+
+  if (func != NULL)
+    {
+      for (l = ret; l != NULL; l = l->next)
+        l->data = func (l->data, user_data);
+    }
+
+  return ret;
+}
