@@ -17,7 +17,7 @@
 
 #include "tests/lib/util.h"
 #include "tests/lib/simple-account.h"
-#include "tests/lib/simple-conn.h"
+#include "tests/lib/contacts-conn.h"
 #include "tests/lib/textchan-null.h"
 #include "tests/lib/simple-channel-dispatcher.h"
 #include "tests/lib/simple-channel-request.h"
@@ -78,7 +78,7 @@ setup (Test *test,
   g_assert (test->account != NULL);
 
   /* Create (service and client sides) connection objects */
-  tp_tests_create_and_connect_conn (TP_TESTS_TYPE_SIMPLE_CONNECTION,
+  tp_tests_create_and_connect_conn (TP_TESTS_TYPE_CONTACTS_CONNECTION,
       "me@test.com", &test->base_connection, &test->connection);
 
   /* Create and register CD */
@@ -189,16 +189,26 @@ create_request (void)
       NULL);
 }
 
+static GVariant *
+floating_request (void)
+{
+  return g_variant_new_parsed (
+      "{ %s: <%s>, %s: <%u>, %s: <%s> }",
+      TP_PROP_CHANNEL_CHANNEL_TYPE, TP_IFACE_CHANNEL_TYPE_TEXT,
+      TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, (guint32) TP_HANDLE_TYPE_CONTACT,
+      TP_PROP_CHANNEL_TARGET_ID, "alice");
+}
+
 static void
 test_handle_create_success (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req;
   TpChannelRequest *chan_req;
 
-  request = create_request ();
-  req = tp_account_channel_request_new (test->account, request, 0);
+  req = tp_account_channel_request_new_text (test->account, 0);
+  tp_account_channel_request_set_target_id (req, TP_HANDLE_TYPE_CONTACT,
+      "alice");
 
   /* We didn't start requesting the channel yet, so there is no
    * ChannelRequest */
@@ -208,7 +218,6 @@ test_handle_create_success (Test *test,
   tp_account_channel_request_create_and_handle_channel_async (req,
       NULL, create_and_handle_cb, test);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
@@ -219,6 +228,15 @@ test_handle_create_success (Test *test,
   g_assert (TP_IS_CHANNEL_REQUEST (chan_req));
   g_assert (tp_account_channel_request_get_channel_request (req) == chan_req);
   g_object_unref (chan_req);
+
+  /* The request had the properties we wanted */
+  g_assert_cmpstr (tp_asv_get_string (test->cd_service->last_request,
+        TP_PROP_CHANNEL_CHANNEL_TYPE), ==, TP_IFACE_CHANNEL_TYPE_TEXT);
+  g_assert_cmpstr (tp_asv_get_string (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TARGET_ID), ==, "alice");
+  g_assert_cmpuint (tp_asv_get_uint32 (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, NULL), ==, TP_HANDLE_TYPE_CONTACT);
+  g_assert_cmpuint (tp_asv_size (test->cd_service->last_request), ==, 3);
 }
 
 /* ChannelDispatcher.CreateChannel() call fails */
@@ -226,25 +244,45 @@ static void
 test_handle_create_fail (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req;
 
-  request = create_request ();
-
-  /* Ask to the CD to fail */
-  tp_asv_set_boolean (request, "CreateChannelFail", TRUE);
-
-  req = tp_account_channel_request_new (test->account, request, 0);
+  req = tp_account_channel_request_new_audio_call (test->account, 666);
+  tp_account_channel_request_set_target_id (req, TP_HANDLE_TYPE_CONTACT,
+      "alice");
+  tp_account_channel_request_set_request_property (req, "com.example.Int",
+      g_variant_new_int32 (17));
+  tp_account_channel_request_set_request_property (req, "com.example.String",
+      g_variant_new_string ("ferret"));
+  /* Ask the CD to fail */
+  tp_account_channel_request_set_request_property (req, "CreateChannelFail",
+      g_variant_new_boolean (TRUE));
 
   tp_account_channel_request_create_and_handle_channel_async (req,
       NULL, create_and_handle_cb, test);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
-  g_assert_error (test->error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT);
   g_assert (test->channel == NULL);
+
+  /* The request had the properties we wanted */
+  g_assert_cmpstr (tp_asv_get_string (test->cd_service->last_request,
+        TP_PROP_CHANNEL_CHANNEL_TYPE), ==, TP_IFACE_CHANNEL_TYPE_CALL);
+  g_assert_cmpstr (tp_asv_get_string (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TARGET_ID), ==, "alice");
+  g_assert_cmpuint (tp_asv_get_uint32 (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, NULL), ==, TP_HANDLE_TYPE_CONTACT);
+  g_assert_cmpuint (tp_asv_get_boolean (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TYPE_CALL_INITIAL_AUDIO, NULL), ==, TRUE);
+  g_assert_cmpstr (tp_asv_get_string (test->cd_service->last_request,
+        "com.example.String"), ==, "ferret");
+  g_assert_cmpuint (tp_asv_get_int32 (test->cd_service->last_request,
+        "com.example.Int", NULL), ==, 17);
+  g_assert_cmpuint (tp_asv_get_boolean (test->cd_service->last_request,
+        "CreateChannelFail", NULL), ==, TRUE);
+  g_assert_cmpuint (tp_asv_size (test->cd_service->last_request), ==, 7);
+  g_assert_cmpuint (test->cd_service->last_user_action_time, ==, 666);
 }
 
 /* ChannelRequest.Proceed() call fails */
@@ -252,25 +290,32 @@ static void
 test_handle_proceed_fail (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req;
 
-  request = create_request ();
-
-  /* Ask to the CD to fail */
-  tp_asv_set_boolean (request, "ProceedFail", TRUE);
-
-  req = tp_account_channel_request_new (test->account, request, 0);
+  req = tp_account_channel_request_new_audio_video_call (test->account, 0);
+  /* Ask the CD to fail */
+  tp_account_channel_request_set_request_property (req, "ProceedFail",
+      g_variant_new_boolean (TRUE));
 
   tp_account_channel_request_create_and_handle_channel_async (req,
       NULL, create_and_handle_cb, test);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
-  g_assert_error (test->error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT);
   g_assert (test->channel == NULL);
+
+  /* The request had the properties we wanted */
+  g_assert_cmpstr (tp_asv_get_string (test->cd_service->last_request,
+        TP_PROP_CHANNEL_CHANNEL_TYPE), ==, TP_IFACE_CHANNEL_TYPE_CALL);
+  g_assert_cmpuint (tp_asv_get_boolean (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TYPE_CALL_INITIAL_AUDIO, NULL), ==, TRUE);
+  g_assert_cmpuint (tp_asv_get_boolean (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TYPE_CALL_INITIAL_VIDEO, NULL), ==, TRUE);
+  g_assert_cmpuint (tp_asv_get_boolean (test->cd_service->last_request,
+        "ProceedFail", NULL), ==, TRUE);
+  g_assert_cmpuint (tp_asv_size (test->cd_service->last_request), ==, 4);
 }
 
 /* ChannelRequest fire the 'Failed' signal */
@@ -278,25 +323,98 @@ static void
 test_handle_cr_failed (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req;
 
-  request = create_request ();
+  req = tp_account_channel_request_new_file_transfer (test->account,
+      "warez.rar", "application/x-rar", G_GUINT64_CONSTANT (1234567890123), 0);
 
   /* Ask to the CR to fire the signal */
-  tp_asv_set_boolean (request, "FireFailed", TRUE);
-
-  req = tp_account_channel_request_new (test->account, request, 0);
+  tp_account_channel_request_set_request_property (req, "FireFailed",
+      g_variant_new_boolean (TRUE));
 
   tp_account_channel_request_create_and_handle_channel_async (req,
       NULL, create_and_handle_cb, test);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
-  g_assert_error (test->error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT);
   g_assert (test->channel == NULL);
+
+  /* The request had the properties we wanted */
+  g_assert_cmpstr (tp_asv_get_string (test->cd_service->last_request,
+        TP_PROP_CHANNEL_CHANNEL_TYPE), ==, TP_IFACE_CHANNEL_TYPE_FILE_TRANSFER);
+  g_assert_cmpstr (tp_asv_get_string (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_FILENAME), ==, "warez.rar");
+  g_assert_cmpuint (tp_asv_get_uint64 (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_SIZE, NULL), ==,
+      G_GUINT64_CONSTANT (1234567890123));
+  g_assert_cmpstr (tp_asv_get_string (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_CONTENT_TYPE), ==,
+      "application/x-rar");
+  g_assert_cmpuint (tp_asv_get_boolean (test->cd_service->last_request,
+        "FireFailed", NULL), ==, TRUE);
+  g_assert_cmpuint (tp_asv_size (test->cd_service->last_request), ==, 5);
+  g_assert_cmpuint (test->cd_service->last_user_action_time, ==, 0);
+}
+
+static void
+test_ft_props (Test *test,
+    gconstpointer data G_GNUC_UNUSED)
+{
+  TpAccountChannelRequest *req;
+
+  req = tp_account_channel_request_new_file_transfer (test->account,
+      "warez.rar", "application/x-rar", G_GUINT64_CONSTANT (1234567890123), 0);
+  tp_account_channel_request_set_file_transfer_description (req,
+      "A collection of l33t warez");
+  tp_account_channel_request_set_file_transfer_initial_offset (req,
+      1024 * 1024);
+  tp_account_channel_request_set_file_transfer_timestamp (req,
+      1111222233);
+  tp_account_channel_request_set_file_transfer_uri (req,
+      "file:///home/Downloads/warez.rar");
+
+  /* Ask to the CR to fire the signal */
+  tp_account_channel_request_set_request_property (req, "FireFailed",
+      g_variant_new_boolean (TRUE));
+
+  tp_account_channel_request_create_and_handle_channel_async (req,
+      NULL, create_and_handle_cb, test);
+
+  g_object_unref (req);
+
+  g_main_loop_run (test->mainloop);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT);
+  g_assert (test->channel == NULL);
+
+  /* The request had the properties we wanted */
+  g_assert_cmpstr (tp_asv_get_string (test->cd_service->last_request,
+        TP_PROP_CHANNEL_CHANNEL_TYPE), ==, TP_IFACE_CHANNEL_TYPE_FILE_TRANSFER);
+  g_assert_cmpstr (tp_asv_get_string (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_FILENAME), ==, "warez.rar");
+  g_assert_cmpuint (tp_asv_get_uint64 (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_SIZE, NULL), ==,
+      G_GUINT64_CONSTANT (1234567890123));
+  g_assert_cmpstr (tp_asv_get_string (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_CONTENT_TYPE), ==,
+      "application/x-rar");
+  g_assert_cmpstr (tp_asv_get_string (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_DESCRIPTION), ==,
+      "A collection of l33t warez");
+  g_assert_cmpstr (tp_asv_get_string (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_URI), ==,
+      "file:///home/Downloads/warez.rar");
+  g_assert_cmpuint (tp_asv_get_uint64 (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_INITIAL_OFFSET, NULL), ==,
+      1024 * 1024);
+  g_assert_cmpuint (tp_asv_get_uint64 (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_DATE, NULL), ==,
+      1111222233);
+  g_assert_cmpuint (tp_asv_get_boolean (test->cd_service->last_request,
+        "FireFailed", NULL), ==, TRUE);
+  g_assert_cmpuint (tp_asv_size (test->cd_service->last_request), ==, 9);
+  g_assert_cmpuint (test->cd_service->last_user_action_time, ==, 0);
 }
 
 static void
@@ -327,11 +445,35 @@ static void
 test_handle_ensure_success (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req;
+  TpContact *alice;
+  GHashTable *asv;
+  GVariant *vardict;
 
-  request = create_request ();
-  req = tp_account_channel_request_new (test->account, request, 0);
+  alice = tp_tests_connection_run_until_contact_by_id (test->connection,
+      "alice", 0, NULL);
+
+  req = tp_account_channel_request_new_text (test->account, 0);
+  tp_account_channel_request_set_target_contact (req, alice);
+
+  asv = (GHashTable *) tp_account_channel_request_get_request (req);
+  vardict = tp_account_channel_request_dup_request (req);
+  g_assert_cmpstr (tp_asv_get_string (asv,
+      TP_PROP_CHANNEL_TARGET_ID), ==, "alice");
+  g_assert_cmpstr (tp_vardict_get_string (vardict,
+      TP_PROP_CHANNEL_TARGET_ID), ==, "alice");
+  g_variant_unref (vardict);
+
+  g_object_get (req,
+      "request", &asv,
+      "request-vardict", &vardict,
+      NULL);
+  g_assert_cmpstr (tp_asv_get_string (asv,
+      TP_PROP_CHANNEL_TARGET_ID), ==, "alice");
+  g_assert_cmpstr (tp_vardict_get_string (vardict,
+      TP_PROP_CHANNEL_TARGET_ID), ==, "alice");
+  g_hash_table_unref (asv);
+  g_variant_unref (vardict);
 
   tp_account_channel_request_ensure_and_handle_channel_async (req,
       NULL, ensure_and_handle_cb, test);
@@ -342,16 +484,27 @@ test_handle_ensure_success (Test *test,
   g_assert_no_error (test->error);
 
   /* Try again, now it will fail as the channel already exist */
-  req = tp_account_channel_request_new (test->account, request, 0);
+  req = tp_account_channel_request_new_text (test->account, 0);
+  tp_account_channel_request_set_target_contact (req, alice);
 
   tp_account_channel_request_ensure_and_handle_channel_async (req,
       NULL, ensure_and_handle_cb, test);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
-  g_assert_error (test->error, TP_ERRORS, TP_ERROR_NOT_YOURS);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_NOT_YOURS);
+
+  g_object_unref (alice);
+
+  /* The request had the properties we wanted */
+  g_assert_cmpstr (tp_asv_get_string (test->cd_service->last_request,
+        TP_PROP_CHANNEL_CHANNEL_TYPE), ==, TP_IFACE_CHANNEL_TYPE_TEXT);
+  g_assert_cmpstr (tp_asv_get_string (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TARGET_ID), ==, "alice");
+  g_assert_cmpuint (tp_asv_get_uint32 (test->cd_service->last_request,
+        TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, NULL), ==, TP_HANDLE_TYPE_CONTACT);
+  g_assert_cmpuint (tp_asv_size (test->cd_service->last_request), ==, 3);
 }
 
 /* Cancel the operation before starting it */
@@ -359,18 +512,16 @@ static void
 test_handle_cancel_before (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req;
 
-  request = create_request ();
-  req = tp_account_channel_request_new (test->account, request, 0);
+  req = tp_account_channel_request_new_vardict (test->account,
+      floating_request (), 0);
 
   g_cancellable_cancel (test->cancellable);
 
   tp_account_channel_request_ensure_and_handle_channel_async (req,
       test->cancellable, create_and_handle_cb, test);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
@@ -390,11 +541,10 @@ static void
 test_handle_cancel_after_create (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req;
 
-  request = create_request ();
-  req = tp_account_channel_request_new (test->account, request, 0);
+  req = tp_account_channel_request_new_vardict (test->account,
+      floating_request (), 0);
 
   tp_account_channel_request_ensure_and_handle_channel_async (req,
       test->cancellable, create_and_handle_cb, test);
@@ -402,11 +552,10 @@ test_handle_cancel_after_create (Test *test,
   g_signal_connect (test->cd_service, "channel-request-created",
       G_CALLBACK (channel_request_created_cb), test);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
-  g_assert_error (test->error, TP_ERRORS, TP_ERROR_CANCELLED);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_CANCELLED);
 }
 
 /* Test if re-handled is properly fired when a channel is
@@ -431,11 +580,10 @@ static void
 test_handle_re_handle (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req, *req2;
 
-  request = create_request ();
-  req = tp_account_channel_request_new (test->account, request, 0);
+  req = tp_account_channel_request_new_vardict (test->account,
+      floating_request (), 0);
 
   tp_account_channel_request_ensure_and_handle_channel_async (req,
       NULL, ensure_and_handle_cb, test);
@@ -447,7 +595,8 @@ test_handle_re_handle (Test *test,
       G_CALLBACK (re_handled_cb), test);
 
   /* Ensure the same channel to re-handle it */
-  req2 = tp_account_channel_request_new (test->account, request, 666);
+  req2 = tp_account_channel_request_new_vardict (test->account,
+      floating_request (), 666);
 
   tp_account_channel_request_ensure_and_handle_channel_async (req2,
       NULL, ensure_and_handle_cb, test);
@@ -456,7 +605,6 @@ test_handle_re_handle (Test *test,
   test->count = 2;
   g_main_loop_run (test->mainloop);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
   g_object_unref (req2);
 }
@@ -514,12 +662,11 @@ static void
 test_handle_create_success_hints (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req;
   GHashTable *hints;
 
-  request = create_request ();
-  req = tp_account_channel_request_new (test->account, request, 0);
+  req = tp_account_channel_request_new_vardict (test->account,
+      floating_request (), 0);
 
   hints = create_hints ();
   tp_account_channel_request_set_hints (req, hints);
@@ -528,7 +675,6 @@ test_handle_create_success_hints (Test *test,
   tp_account_channel_request_create_and_handle_channel_async (req,
       NULL, create_and_handle_hints_cb, test);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
@@ -599,7 +745,6 @@ static void
 test_handle_delegated (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req;
   GPtrArray *requests, *requests_satisified, *channels;
   GHashTable *hints, *request_props, *info;
@@ -607,8 +752,8 @@ test_handle_delegated (Test *test,
   TpBaseClient *base_client;
   TpClient *client;
 
-  request = create_request ();
-  req = tp_account_channel_request_new (test->account, request, 0);
+  req = tp_account_channel_request_new_vardict (test->account,
+      floating_request (), 0);
 
   /* Allow other clients to preempt the channel */
   tp_account_channel_request_set_delegated_channel_callback (req,
@@ -617,7 +762,6 @@ test_handle_delegated (Test *test,
   tp_account_channel_request_create_and_handle_channel_async (req,
       NULL, create_and_handle_cb, test);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
@@ -705,16 +849,14 @@ static void
 test_forget_create_success (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req;
 
-  request = create_request ();
-  req = tp_account_channel_request_new (test->account, request, 0);
+  req = tp_account_channel_request_new_vardict (test->account,
+      floating_request (), 0);
 
   tp_account_channel_request_create_channel_async (req, "Fake", NULL, create_cb,
       test);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
@@ -739,16 +881,14 @@ static void
 test_forget_ensure_success (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req;
 
-  request = create_request ();
-  req = tp_account_channel_request_new (test->account, request, 0);
+  req = tp_account_channel_request_new_vardict (test->account,
+      floating_request (), 0);
 
   tp_account_channel_request_ensure_channel_async (req, "Fake", NULL, ensure_cb,
       test);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
@@ -777,7 +917,7 @@ test_forget_create_fail (Test *test,
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
-  g_assert_error (test->error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT);
   g_assert (test->channel == NULL);
 }
 
@@ -803,7 +943,7 @@ test_forget_proceed_fail (Test *test,
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
-  g_assert_error (test->error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT);
   g_assert (test->channel == NULL);
 }
 
@@ -829,7 +969,7 @@ test_forget_cr_failed (Test *test,
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
-  g_assert_error (test->error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT);
   g_assert (test->channel == NULL);
 }
 
@@ -838,18 +978,16 @@ static void
 test_forget_cancel_before (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req;
 
-  request = create_request ();
-  req = tp_account_channel_request_new (test->account, request, 0);
+  req = tp_account_channel_request_new_vardict (test->account,
+      floating_request (), 0);
 
   g_cancellable_cancel (test->cancellable);
 
   tp_account_channel_request_create_channel_async (req, "Fake",
       test->cancellable, create_cb, test);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
@@ -860,11 +998,10 @@ static void
 test_forget_cancel_after_create (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req;
 
-  request = create_request ();
-  req = tp_account_channel_request_new (test->account, request, 0);
+  req = tp_account_channel_request_new_vardict (test->account,
+      floating_request (), 0);
 
   tp_account_channel_request_create_channel_async (req, "Fake",
       test->cancellable, create_cb, test);
@@ -872,11 +1009,10 @@ test_forget_cancel_after_create (Test *test,
   g_signal_connect (test->cd_service, "channel-request-created",
       G_CALLBACK (channel_request_created_cb), test);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
-  g_assert_error (test->error, TP_ERRORS, TP_ERROR_CANCELLED);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_CANCELLED);
 }
 
 /* Request and observe tests */
@@ -904,16 +1040,14 @@ static void
 test_observe_create_success (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req;
 
-  request = create_request ();
-  req = tp_account_channel_request_new (test->account, request, 0);
+  req = tp_account_channel_request_new_vardict (test->account,
+      floating_request (), 0);
 
   tp_account_channel_request_create_and_observe_channel_async (req, "Fake",
       NULL, create_and_observe_cb, test);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
@@ -942,7 +1076,7 @@ test_observe_create_fail (Test *test,
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
-  g_assert_error (test->error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT);
   g_assert (test->channel == NULL);
 }
 
@@ -968,7 +1102,7 @@ test_observe_proceed_fail (Test *test,
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
-  g_assert_error (test->error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT);
   g_assert (test->channel == NULL);
 }
 
@@ -994,7 +1128,7 @@ test_observe_cr_failed (Test *test,
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
-  g_assert_error (test->error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT);
   g_assert (test->channel == NULL);
 }
 
@@ -1022,16 +1156,14 @@ static void
 test_observe_ensure_success (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req;
 
-  request = create_request ();
-  req = tp_account_channel_request_new (test->account, request, 0);
+  req = tp_account_channel_request_new_vardict (test->account,
+      floating_request (), 0);
 
   tp_account_channel_request_ensure_and_observe_channel_async (req, "Fake",
       NULL, ensure_and_observe_cb, test);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
@@ -1043,18 +1175,16 @@ static void
 test_observe_cancel_before (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req;
 
-  request = create_request ();
-  req = tp_account_channel_request_new (test->account, request, 0);
+  req = tp_account_channel_request_new_vardict (test->account,
+      floating_request (), 0);
 
   g_cancellable_cancel (test->cancellable);
 
   tp_account_channel_request_create_and_observe_channel_async (req, "Fake",
       test->cancellable, create_and_observe_cb, test);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
@@ -1065,11 +1195,10 @@ static void
 test_observe_cancel_after_create (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req;
 
-  request = create_request ();
-  req = tp_account_channel_request_new (test->account, request, 0);
+  req = tp_account_channel_request_new_vardict (test->account,
+      floating_request (), 0);
 
   tp_account_channel_request_create_and_observe_channel_async (req, "Fake",
       test->cancellable, create_and_observe_cb, test);
@@ -1077,11 +1206,10 @@ test_observe_cancel_after_create (Test *test,
   g_signal_connect (test->cd_service, "channel-request-created",
       G_CALLBACK (channel_request_created_cb), test);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
-  g_assert_error (test->error, TP_ERRORS, TP_ERROR_CANCELLED);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_CANCELLED);
 }
 
 /* Succeeded is fired but not SucceededWithChannel */
@@ -1089,20 +1217,18 @@ static void
 test_observe_no_channel (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
-  GHashTable *request;
   TpAccountChannelRequest *req;
 
-  request = create_request ();
-  req = tp_account_channel_request_new (test->account, request, 0);
+  req = tp_account_channel_request_new_vardict (test->account,
+      floating_request (), 0);
 
   tp_account_channel_request_create_and_observe_channel_async (req,
       "FakeNoChannel", NULL, create_and_observe_cb, test);
 
-  g_hash_table_unref (request);
   g_object_unref (req);
 
   g_main_loop_run (test->mainloop);
-  g_assert_error (test->error, TP_ERRORS, TP_ERROR_CONFUSED);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_CONFUSED);
 }
 
 int
@@ -1168,5 +1294,9 @@ main (int argc,
   g_test_add ("/account-channels/request-observe/no-channel", Test, NULL,
       setup, test_observe_no_channel, teardown);
 
+  /* Particular properties of the request */
+  g_test_add ("/account-channels/test-ft-props", Test, NULL,
+      setup, test_ft_props, teardown);
+
   return g_test_run ();
 }
