@@ -130,7 +130,7 @@ main (int argc,
   gchar *bad_chan_path;
   TpHandle handle;
   gboolean was_ready;
-  GError invalidated_for_test = { TP_ERRORS, TP_ERROR_PERMISSION_DENIED,
+  GError invalidated_for_test = { TP_ERROR, TP_ERROR_PERMISSION_DENIED,
       "No channel for you!" };
   GHashTable *asv;
   GAsyncResult *prepare_result;
@@ -374,8 +374,10 @@ main (int argc,
   g_object_unref (prepare_result);
   prepare_result = NULL;
 
-  assert_chan_sane (chan, handle, TRUE, service_conn_as_base->self_handle,
-      tp_handle_inspect (contact_repo, service_conn_as_base->self_handle));
+  assert_chan_sane (chan, handle, TRUE,
+      tp_base_connection_get_self_handle (service_conn_as_base),
+      tp_handle_inspect (contact_repo,
+        tp_base_connection_get_self_handle (service_conn_as_base)));
 
   /* no way to see what this is doing - just make sure it doesn't crash */
   tp_proxy_prepare_async (chan, some_features, NULL, NULL);
@@ -770,7 +772,7 @@ main (int argc,
 
   tp_channel_call_when_ready (chan, channel_ready, &was_ready);
   g_assert (was_ready);
-  g_assert_error (invalidated, TP_ERRORS, TP_ERROR_CANCELLED);
+  g_assert_error (invalidated, TP_ERROR, TP_ERROR_CANCELLED);
 
   /* is_prepared becomes FALSE because the channel broke */
   g_assert_cmpint (tp_proxy_is_prepared (chan, TP_CHANNEL_FEATURE_CORE), ==,
