@@ -320,8 +320,8 @@ check_invalidated_unknown_error_cb (TpProxy *proxy,
 
   /* Because we didn't understand the D-Bus error string, the Telepathy error
    * is derived from the Channel_Group_Change_Reason; since 0.11.5
-   * it's remapped into the TP_ERRORS domain if possible */
-  g_assert_error (error, TP_ERRORS, TP_ERROR_NO_ANSWER);
+   * it's remapped into the TP_ERROR domain if possible */
+  g_assert_error (error, TP_ERROR, TP_ERROR_NO_ANSWER);
   MYASSERT (strstr (message, REMOVED_UNKNOWN_ERROR) != NULL, " (%s, %s)",
       message, REMOVED_UNKNOWN_ERROR);
   MYASSERT (strstr (message, REMOVED_MESSAGE) != NULL, " (%s, %s)", message,
@@ -411,7 +411,7 @@ check_invalidated_known_error_cb (TpProxy *proxy,
   MYASSERT (!*invalidated, "");
   *invalidated = TRUE;
 
-  g_assert_error (error, TP_ERRORS, REMOVED_KNOWN_ERROR_CODE);
+  g_assert_error (error, TP_ERROR, REMOVED_KNOWN_ERROR_CODE);
   MYASSERT (strstr (message, REMOVED_KNOWN_ERROR_STR) == NULL, " (%s, %s)",
       message, REMOVED_KNOWN_ERROR_STR);
   MYASSERT (strstr (message, REMOVED_MESSAGE) != NULL, " (%s, %s)", message,
