@@ -1,5 +1,7 @@
 /* Regression test for fd.o bug #19101. */
 
+#include "config.h"
+
 #include <telepathy-glib/connection.h>
 #include <telepathy-glib/contact.h>
 #include <telepathy-glib/dbus.h>
@@ -177,9 +179,7 @@ main (int argc,
 
   /* Teardown */
 
-  MYASSERT (tp_cli_connection_run_disconnect (client_conn, -1, &error, NULL),
-      "");
-  g_assert_no_error (error);
+  tp_tests_connection_assert_disconnect_succeeds (client_conn);
   g_object_unref (client_conn);
 
   service_conn_as_base = NULL;
