@@ -277,16 +277,14 @@ test_properties (Test *test,
 {
   create_simple_approver (test, add_dispatch_success);
 
-  tp_base_client_take_approver_filter (test->simple_approver, tp_asv_new (
-        TP_PROP_CHANNEL_CHANNEL_TYPE, G_TYPE_STRING, TP_IFACE_CHANNEL_TYPE_TEXT,
-        NULL));
+  tp_base_client_add_approver_filter_vardict (test->simple_approver,
+      g_variant_new_parsed ("{ %s: <%s> }",
+        TP_PROP_CHANNEL_CHANNEL_TYPE, TP_IFACE_CHANNEL_TYPE_TEXT));
 
-  tp_base_client_take_approver_filter (test->simple_approver, tp_asv_new (
-        TP_PROP_CHANNEL_CHANNEL_TYPE, G_TYPE_STRING,
-          TP_IFACE_CHANNEL_TYPE_STREAM_TUBE,
-        TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, G_TYPE_UINT,
-          TP_HANDLE_TYPE_CONTACT,
-        NULL));
+  tp_base_client_add_approver_filter_vardict (test->simple_approver,
+      g_variant_new_parsed ("{ %s: <%s>, %s: <%u> }",
+        TP_PROP_CHANNEL_CHANNEL_TYPE, TP_IFACE_CHANNEL_TYPE_STREAM_TUBE,
+        TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, (guint32) TP_HANDLE_TYPE_CONTACT));
 
   tp_base_client_register (test->simple_approver, &test->error);
   g_assert_no_error (test->error);
@@ -394,8 +392,8 @@ test_success (Test *test,
 {
   create_simple_approver (test, add_dispatch_success);
 
-  tp_base_client_take_approver_filter (test->simple_approver,
-      g_hash_table_new (NULL, NULL));
+  tp_base_client_add_approver_filter_vardict (test->simple_approver,
+      g_variant_new_parsed ("@a{sv} {}"));
 
   tp_base_client_register (test->simple_approver, &test->error);
   g_assert_no_error (test->error);
@@ -440,8 +438,8 @@ test_delayed (Test *test,
 {
   create_simple_approver (test, add_dispatch_async);
 
-  tp_base_client_take_approver_filter (test->simple_approver,
-      g_hash_table_new (NULL, NULL));
+  tp_base_client_add_approver_filter_vardict (test->simple_approver,
+      g_variant_new_parsed ("@a{sv} {}"));
 
   tp_base_client_register (test->simple_approver, &test->error);
   g_assert_no_error (test->error);
@@ -461,7 +459,7 @@ add_dispatch_fail (
     TpAddDispatchOperationContext *context,
     gpointer user_data)
 {
-  GError error = { TP_ERRORS, TP_ERROR_NOT_AVAILABLE,
+  GError error = { TP_ERROR, TP_ERROR_NOT_AVAILABLE,
       "No AddDispatchOperation for you!" };
 
   tp_add_dispatch_operation_context_fail (context, &error);
@@ -473,14 +471,14 @@ test_fail (Test *test,
 {
   create_simple_approver (test, add_dispatch_fail);
 
-  tp_base_client_take_approver_filter (test->simple_approver,
-      g_hash_table_new (NULL, NULL));
+  tp_base_client_add_approver_filter_vardict (test->simple_approver,
+      g_variant_new_parsed ("@a{sv} {}"));
 
   tp_base_client_register (test->simple_approver, &test->error);
   g_assert_no_error (test->error);
 
   call_add_dispatch (test);
-  g_assert_error (test->error, TP_ERRORS, TP_ERROR_NOT_AVAILABLE);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_NOT_AVAILABLE);
 }
 
 int
