@@ -51,7 +51,7 @@ TestContext contexts[] = {
   { TRUE, TP_SOCKET_ADDRESS_TYPE_IPV6, TP_SOCKET_ACCESS_CONTROL_LOCALHOST },
   { TRUE, TP_SOCKET_ADDRESS_TYPE_IPV4, TP_SOCKET_ACCESS_CONTROL_PORT },
 
-  { FALSE, NUM_TP_SOCKET_ADDRESS_TYPES, NUM_TP_SOCKET_ACCESS_CONTROLS }
+  { FALSE, TP_NUM_SOCKET_ADDRESS_TYPES, TP_NUM_SOCKET_ACCESS_CONTROLS }
 };
 
 static gboolean have_ipv6 = FALSE;
@@ -231,12 +231,24 @@ test_creation (Test *test,
 }
 
 static void
-check_parameters (GHashTable *parameters)
+check_parameters (GHashTable *parameters,
+    GVariant *parameters_vardict)
 {
+  gboolean found;
+  guint32 u32;
+
   g_assert (parameters != NULL);
+  g_assert (parameters_vardict != NULL);
+  g_assert_cmpstr (g_variant_get_type_string (parameters_vardict), ==,
+      "a{sv}");
 
   g_assert_cmpuint (g_hash_table_size (parameters), ==, 1);
+  g_assert_cmpuint (g_variant_n_children (parameters_vardict), ==, 1);
+
   g_assert_cmpuint (tp_asv_get_uint32 (parameters, "badger", NULL), ==, 42);
+  found = g_variant_lookup (parameters_vardict, "badger", "u", &u32);
+  g_assert_cmpint (found, ==, TRUE);
+  g_assert_cmpuint (u32, ==, 42);
 }
 
 static void
@@ -245,6 +257,7 @@ test_properties (Test *test,
 {
   gchar *service;
   GHashTable *parameters;
+  GVariant *parameters_vardict;
 
   /* Outgoing tube */
   create_tube_service (test, TRUE, TP_SOCKET_ADDRESS_TYPE_UNIX,
@@ -259,10 +272,18 @@ test_properties (Test *test,
 
   /* Parameters */
   parameters = tp_stream_tube_channel_get_parameters (test->tube);
-  /* NULL as the tube has not be offered yet */
+  /* NULL as the tube has not been offered yet */
   g_assert (parameters == NULL);
   g_object_get (test->tube, "parameters", &parameters, NULL);
   g_assert (parameters == NULL);
+  parameters_vardict = tp_stream_tube_channel_dup_parameters_vardict (
+      test->tube);
+  /* NULL as the tube has not been offered yet */
+  g_assert (parameters_vardict == NULL);
+  g_object_get (test->tube,
+      "parameters-vardict", &parameters_vardict,
+      NULL);
+  g_assert (parameters_vardict == NULL);
 
   /* Incoming tube */
   create_tube_service (test, FALSE, TP_SOCKET_ADDRESS_TYPE_UNIX,
@@ -270,10 +291,20 @@ test_properties (Test *test,
 
   /* Parameters */
   parameters = tp_stream_tube_channel_get_parameters (test->tube);
-  check_parameters (parameters);
-  g_object_get (test->tube, "parameters", &parameters, NULL);
-  check_parameters (parameters);
+  parameters_vardict = tp_stream_tube_channel_dup_parameters_vardict (
+      test->tube);
+  check_parameters (parameters, parameters_vardict);
+  g_variant_unref (parameters_vardict);
+
+  g_object_get (test->tube,
+      "parameters", &parameters,
+      "parameters-vardict", &parameters_vardict,
+      NULL);
+
+  g_assert (parameters_vardict != NULL);
+  check_parameters (parameters, parameters_vardict);
   g_hash_table_unref (parameters);
+  g_variant_unref (parameters_vardict);
 }
 
 static void
@@ -535,6 +566,7 @@ test_offer_success (Test *test,
   GSocketClient *client;
   TpHandle bob_handle;
   TpContact *contact;
+  GVariant *parameters_vardict;
 
   if (contexts[i].address_type == TP_SOCKET_ADDRESS_TYPE_UNIX &&
       contexts[i].access_control == TP_SOCKET_ACCESS_CONTROL_CREDENTIALS &&
@@ -561,7 +593,11 @@ test_offer_success (Test *test,
   tp_stream_tube_channel_offer_async (test->tube, params, tube_offer_cb, test);
   g_hash_table_unref (params);
 
-  check_parameters (tp_stream_tube_channel_get_parameters (test->tube));
+  parameters_vardict = tp_stream_tube_channel_dup_parameters_vardict (
+      test->tube);
+  check_parameters (tp_stream_tube_channel_get_parameters (test->tube),
+      parameters_vardict);
+  g_variant_unref (parameters_vardict);
 
   test->wait = 1;
   g_main_loop_run (test->mainloop);
@@ -644,7 +680,7 @@ test_accept_twice (Test *test,
   tp_stream_tube_channel_accept_async (test->tube, tube_accept_cb, test);
   test->wait = 1;
   g_main_loop_run (test->mainloop);
-  g_assert_error (test->error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT);
 }
 
 static void
@@ -659,7 +695,7 @@ test_accept_outgoing (Test *test,
 
   test->wait = 1;
   g_main_loop_run (test->mainloop);
-  g_assert_error (test->error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT);
 }
 
 typedef void (*TestFunc) (Test *, gconstpointer);
@@ -715,7 +751,7 @@ run_tube_test (const char *test_path,
 {
   guint i;
 
-  for (i = 0; contexts[i].address_type != NUM_TP_SOCKET_ADDRESS_TYPES; i++)
+  for (i = 0; contexts[i].address_type != TP_NUM_SOCKET_ADDRESS_TYPES; i++)
     {
       gchar *path = test_context_to_str (&contexts[i], test_path);
 
