@@ -79,8 +79,11 @@ struct _TpTestsFileTransferChannelPrivate {
     TpSocketAddressType address_type;
     GValue *address;
     gchar *unix_address;
+    gchar *unix_tmpdir;
     guint connection_id;
     TpSocketAccessControl access_control;
+
+    guint timer_id;
 };
 
 static void
@@ -135,6 +138,12 @@ dispose (GObject *object)
 {
   TpTestsFileTransferChannel *self = TP_TESTS_FILE_TRANSFER_CHANNEL (object);
 
+  if (self->priv->timer_id != 0)
+    {
+      g_source_remove (self->priv->timer_id);
+      self->priv->timer_id = 0;
+    }
+
   g_free (self->priv->content_hash);
   g_free (self->priv->content_type);
   g_free (self->priv->description);
@@ -152,6 +161,11 @@ dispose (GObject *object)
 
   tp_clear_pointer (&self->priv->unix_address, g_free);
 
+  if (self->priv->unix_tmpdir != NULL)
+    g_rmdir (self->priv->unix_tmpdir);
+
+  tp_clear_pointer (&self->priv->unix_tmpdir, g_free);
+
   ((GObjectClass *) tp_tests_file_transfer_channel_parent_class)->dispose (
       object);
 }
@@ -364,6 +378,7 @@ start_file_transfer (gpointer data)
 //  g_signal_connect (self->priv->service, "incoming", G_CALLBACK
 //      (incoming_file_transfer_cb));
 
+  self->priv->timer_id = 0;
   return FALSE;
 }
 
@@ -472,7 +487,8 @@ file_transfer_provide_file (TpSvcChannelTypeFileTransfer *iface,
     }
 
   self->priv->address = _tp_create_local_socket (address_type, access_control,
-      &self->priv->service, &self->priv->unix_address, &error);
+      &self->priv->service, &self->priv->unix_address,
+      &self->priv->unix_tmpdir, &error);
 
   if (self->priv->address == NULL)
       {
@@ -485,7 +501,7 @@ file_transfer_provide_file (TpSvcChannelTypeFileTransfer *iface,
   self->priv->access_control = access_control;
 
   DEBUG ("Waiting 500ms and setting state to OPEN");
-  g_timeout_add (500, start_file_transfer, self);
+  self->priv->timer_id = g_timeout_add (500, start_file_transfer, self);
 
   // connect to self->priv->service incoming signal
   // when the signal returns, add x bytes per n seconds using timeout
@@ -538,7 +554,8 @@ file_transfer_accept_file (TpSvcChannelTypeFileTransfer *iface,
     }
 
   address = _tp_create_local_socket (address_type, access_control,
-      &self->priv->service, &self->priv->unix_address, &error);
+      &self->priv->service, &self->priv->unix_address,
+      &self->priv->unix_tmpdir, &error);
 
   tp_g_signal_connect_object (self->priv->service, "incoming",
       G_CALLBACK (service_incoming_cb), self, 0);
@@ -552,7 +569,7 @@ file_transfer_accept_file (TpSvcChannelTypeFileTransfer *iface,
       TP_FILE_TRANSFER_STATE_CHANGE_REASON_REQUESTED);
 
   DEBUG ("Waiting 500ms and setting state to OPEN");
-  g_timeout_add (500, start_file_transfer, self);
+  self->priv->timer_id = g_timeout_add (500, start_file_transfer, self);
 
   tp_svc_channel_type_file_transfer_return_from_accept_file (context,
       address);
