@@ -1,7 +1,7 @@
 /*
  * simple-account.h - header for a simple account service.
  *
- * Copyright (C) 2010 Collabora Ltd. <http://www.collabora.co.uk/>
+ * Copyright (C) 2010-2012 Collabora Ltd. <http://www.collabora.co.uk/>
  *
  * Copying and distribution of this file, with or without modification,
  * are permitted in any medium without royalty provided the copyright
@@ -57,6 +57,16 @@ void tp_tests_simple_account_set_presence (TpTestsSimpleAccount *self,
     const gchar *status,
     const gchar *message);
 
+void tp_tests_simple_account_set_connection (TpTestsSimpleAccount *self,
+    const gchar *object_path);
+
+void tp_tests_simple_account_removed (TpTestsSimpleAccount *self);
+void tp_tests_simple_account_set_enabled (TpTestsSimpleAccount *self,
+    gboolean enabled);
+
+void tp_tests_simple_account_add_uri_scheme (TpTestsSimpleAccount *self,
+    const gchar * uri_scheme);
+
 G_END_DECLS
 
 #endif /* #ifndef __TP_TESTS_SIMPLE_ACCOUNT_H__ */
