@@ -56,6 +56,7 @@ struct _TpTestsStreamTubeChannelPrivate {
     TpSocketAddressType address_type;
     GValue *address;
     gchar *unix_address;
+    gchar *unix_tmpdir;
     guint connection_id;
 
     TpSocketAccessControl access_control;
@@ -211,6 +212,11 @@ dispose (GObject *object)
 
   tp_clear_pointer (&self->priv->unix_address, g_free);
 
+  if (self->priv->unix_tmpdir != NULL)
+    g_rmdir (self->priv->unix_tmpdir);
+
+  tp_clear_pointer (&self->priv->unix_tmpdir, g_free);
+
   ((GObjectClass *) tp_tests_stream_tube_channel_parent_class)->dispose (
     object);
 }
@@ -482,7 +488,8 @@ stream_tube_accept (TpSvcChannelTypeStreamTube *iface,
     }
 
   address = _tp_create_local_socket (address_type, access_control,
-      &self->priv->service, &self->priv->unix_address, &error);
+      &self->priv->service, &self->priv->unix_address,
+      &self->priv->unix_tmpdir, &error);
   tp_g_signal_connect_object (self->priv->service, "incoming",
       G_CALLBACK (service_incoming_cb), self, 0);
 
