@@ -10,7 +10,7 @@
 
 #include "config.h"
 
-#include "tests/lib/util.h"
+#include "util.h"
 
 #include <telepathy-glib/connection.h>
 
@@ -114,50 +114,6 @@ tp_tests_proxy_run_until_dbus_queue_processed (gpointer proxy)
   g_main_loop_unref (loop);
 }
 
-typedef struct {
-    GMainLoop *loop;
-    TpHandle handle;
-} HandleRequestResult;
-
-static void
-handles_requested_cb (TpConnection *connection G_GNUC_UNUSED,
-    TpHandleType handle_type G_GNUC_UNUSED,
-    guint n_handles,
-    const TpHandle *handles,
-    const gchar * const *ids G_GNUC_UNUSED,
-    const GError *error,
-    gpointer user_data,
-    GObject *weak_object G_GNUC_UNUSED)
-{
-  HandleRequestResult *result = user_data;
-
-  g_assert_no_error ((GError *) error);
-  g_assert_cmpuint (n_handles, ==, 1);
-  result->handle = handles[0];
-}
-
-static void
-handle_request_result_finish (gpointer r)
-{
-  HandleRequestResult *result = r;
-
-  g_main_loop_quit (result->loop);
-}
-
-TpHandle
-tp_tests_connection_run_request_contact_handle (TpConnection *connection,
-    const gchar *id)
-{
-  HandleRequestResult result = { g_main_loop_new (NULL, FALSE), 0 };
-  const gchar * const ids[] = { id, NULL };
-
-  tp_connection_request_handles (connection, -1, TP_HANDLE_TYPE_CONTACT, ids,
-      handles_requested_cb, &result, handle_request_result_finish, NULL);
-  g_main_loop_run (result.loop);
-  g_main_loop_unref (result.loop);
-  return result.handle;
-}
-
 void
 _test_assert_empty_strv (const char *file,
     int line,
@@ -219,6 +175,26 @@ _tp_tests_assert_strv_equals (const char *file,
     }
 }
 
+void
+_tp_tests_assert_bytes_equal (const gchar *file, int line,
+  GBytes *actual, gconstpointer expected_data,
+  gsize expected_length)
+{
+  if (expected_length != g_bytes_get_size (actual))
+    {
+      g_error ("%s:%d: assertion failed: expected %"G_GSIZE_FORMAT
+         " bytes, got %"G_GSIZE_FORMAT,
+        file, line, expected_length, g_bytes_get_size (actual));
+    }
+  else if (memcmp (g_bytes_get_data (actual, NULL),
+      expected_data, expected_length) != 0)
+    {
+      g_error (
+        "%s:%d: assertion failed: expected data didn't match the actual data",
+        file, line);
+    }
+}
+
 void
 tp_tests_create_conn (GType conn_type,
     const gchar *account,
@@ -227,6 +203,7 @@ tp_tests_create_conn (GType conn_type,
     TpConnection **client_conn)
 {
   TpDBusDaemon *dbus;
+  TpSimpleClientFactory *factory;
   gchar *name;
   gchar *conn_path;
   GError *error = NULL;
@@ -235,6 +212,7 @@ tp_tests_create_conn (GType conn_type,
   g_assert (client_conn != NULL);
 
   dbus = tp_tests_dbus_daemon_dup_or_die ();
+  factory = (TpSimpleClientFactory *) tp_automatic_client_factory_new (dbus);
 
   *service_conn = tp_tests_object_new_static_class (
         conn_type,
@@ -247,8 +225,8 @@ tp_tests_create_conn (GType conn_type,
         &name, &conn_path, &error));
   g_assert_no_error (error);
 
-  *client_conn = tp_connection_new (dbus, name, conn_path,
-      &error);
+  *client_conn = tp_simple_client_factory_ensure_connection (factory,
+      conn_path, NULL, &error);
   g_assert (*client_conn != NULL);
   g_assert_no_error (error);
 
@@ -264,6 +242,7 @@ tp_tests_create_conn (GType conn_type,
   g_free (conn_path);
 
   g_object_unref (dbus);
+  g_object_unref (factory);
 }
 
 void
@@ -359,6 +338,7 @@ _tp_create_local_socket (TpSocketAddressType address_type,
     TpSocketAccessControl access_control,
     GSocketService **service,
     gchar **unix_address,
+    gchar **unix_tmpdir,
     GError **error)
 {
   gboolean success;
@@ -384,7 +364,20 @@ _tp_create_local_socket (TpSocketAddressType address_type,
 #ifdef HAVE_GIO_UNIX
       case TP_SOCKET_ADDRESS_TYPE_UNIX:
         {
-          address = g_unix_socket_address_new (tmpnam (NULL));
+          GError *e = NULL;
+          gchar *dir = g_dir_make_tmp ("tp-glib-tests.XXXXXX", &e);
+          gchar *name;
+
+          g_assert_no_error (e);
+
+          name = g_build_filename (dir, "s", NULL);
+          address = g_unix_socket_address_new (name);
+          g_free (name);
+
+          if (unix_tmpdir != NULL)
+            *unix_tmpdir = dir;
+          else
+            g_free (dir);
           break;
         }
 #endif
@@ -471,3 +464,36 @@ tp_tests_connection_assert_disconnect_succeeds (TpConnection *connection)
   g_assert (ok);
   g_object_unref (result);
 }
+
+static void
+one_contact_cb (GObject *object,
+    GAsyncResult *result,
+    gpointer user_data)
+{
+  TpConnection *connection = (TpConnection *) object;
+  TpContact **contact_loc = user_data;
+  GError *error = NULL;
+
+  *contact_loc = tp_connection_dup_contact_by_id_finish (connection, result,
+      &error);
+
+  g_assert_no_error (error);
+  g_assert (TP_IS_CONTACT (*contact_loc));
+}
+
+TpContact *
+tp_tests_connection_run_until_contact_by_id (TpConnection *connection,
+    const gchar *id,
+    guint n_features,
+    const TpContactFeature *features)
+{
+  TpContact *contact = NULL;
+
+  tp_connection_dup_contact_by_id_async (connection, id, n_features, features,
+      one_contact_cb, &contact);
+
+  while (contact == NULL)
+    g_main_context_iteration (NULL, TRUE);
+
+  return contact;
+}
